<?php
//Create Coupon Post Type
function coupon_init($action) {
	$enable_archive = true;
	$archive_slug = 'coupons';
	$prepend_permalink = false;
	$exclude_from_search = false;
	$show_in_rest_api = false;
	if($action != 'activate') {
		$display_options = get_option('wp_coupons_display_options');
		if(empty($display_options['wp_coupons_enable_archive'])) {
			$enable_archive = false;
		}
		if(!empty($display_options['wp_coupons_archive_slug'])) {
			$archive_slug = $display_options['wp_coupons_archive_slug'];
		}
		$extra_options = get_option('wp_coupons_extra_options');
		if(!empty($extra_options['wp_coupons_prepend_permalink']) && $extra_options['wp_coupons_prepend_permalink'] == "1") {
			$prepend_permalink = true;
		}
		if(!empty($extra_options['wp_coupons_exclude_from_search']) && $extra_options['wp_coupons_exclude_from_search'] == "1") {
			$exclude_from_search = true;
		}
		if(!empty($extra_options['wp_coupons_rest_api']) && $extra_options['wp_coupons_rest_api'] == "1") {
			$show_in_rest_api = true;
		}
	}

	$labels = array(
		'name'               => __('Coupons', 'wp_coupons'),
		'singular_name'      => __('Coupon', 'wp_coupons'),
		'menu_name'          => __('Coupons', 'wp_coupons'),
		'name_admin_bar'     => __('Coupon', 'wp_coupons'),
		'add_new'            => __('Add New', 'wp_coupons'),
		'add_new_item'       => __('Add New Coupon', 'wp_coupons'),
		'new_item'           => __('New Coupon', 'wp_coupons'),
		'edit_item'          => __('Edit Coupon', 'wp_coupons'),
		'view_item'          => __('View Coupon', 'wp_coupons'),
		'all_items'          => __('Coupons', 'wp_coupons'),
		'search_items'       => __('Search Coupons', 'wp_coupons'),
		'parent_item_colon'  => __('Parent Coupon', 'wp_coupons') . ':',
		'not_found'          => __('No coupons found.', 'wp_coupons'),
		'not_found_in_trash' => __('No coupons found in Trash.', 'wp_coupons')
	);

	$args = array(
		'labels'              => $labels,
		'public'              => true,
		'exclude_from_search' => $exclude_from_search,
		'menu_icon'           => 'dashicons-tag',
		'query_var'           => true,
		'capability_type'     => array('coupon','coupons'),
        'map_meta_cap'        => true,
		'hierarchical'        => false,
		'supports'            => array( 'title', 'editor', 'author', 'thumbnail' ),
		'has_archive'         => $enable_archive,
		'rewrite'             => array('slug' => $archive_slug, 'with_front' => $prepend_permalink),
		'show_in_rest'        => $show_in_rest_api
	);
	register_post_type('coupon', $args);
}
add_action('init', 'coupon_init');

//Create Custom Coupon Type Taxonomy
function create_coupon_type_tax($action) {
	$archive_slug = 'coupons';
	$prepend_permalink = false;
	if($action != 'activate') {
		$display_options = get_option('wp_coupons_display_options');
		if(!empty($display_options['wp_coupons_archive_slug'])) {
			$archive_slug = $display_options['wp_coupons_archive_slug'];
		}
		$extra_options = get_option('wp_coupons_extra_options');
		if(!empty($extra_options['wp_coupons_prepend_permalink']) && $extra_options['wp_coupons_prepend_permalink'] == "1") {
			$prepend_permalink = true;
		}
	}
	$labels = array(
		'name'              => __('Types', 'wp_coupons'),
		'singular_name'     => __('Type', 'wp_coupons'),
		'search_items'      => __('Search Types', 'wp_coupons'),
		'all_items'         => __('All Types', 'wp_coupons'),
		'parent_item'       => __('Parent Type', 'wp_coupons'),
		'parent_item_colon' => __('Parent Type', 'wp_coupons') . ':',
		'edit_item'         => __('Edit Type', 'wp_coupons'),
		'update_item'       => __('Update Type', 'wp_coupons'),
		'add_new_item'      => __('Add New Type', 'wp_coupons'),
		'new_item_name'     => __('New Type Name', 'wp_coupons'),
		'menu_name'         => __('Types', 'wp_coupons'),
	);

	$args = array(
		'hierarchical'      => true,
		'labels'            => $labels,
		'show_ui'           => true,
		'show_admin_column' => true,
		'query_var'         => true,
		'has_archive'       => true,
		'rewrite'           => array('slug' => 'all-' . $archive_slug, 'with_front' => $prepend_permalink)
	);
	register_taxonomy('type', array('coupon'), $args);
}
add_action('init', 'create_coupon_type_tax');

//Create Custom Coupon Tag Taxonomy
function create_coupon_tag_tax($action) {
	$labels = array(
		'name'              => __('Tags', 'wp_coupons'),
		'singular_name'     => __('Tag', 'wp_coupons'),
		'search_items'      => __('Search Tags', 'wp_coupons'),
		'all_items'         => __('All Tags', 'wp_coupons'),
		'parent_item'       => __('Parent Tag', 'wp_coupons'),
		'parent_item_colon' => __('Parent Tag', 'wp_coupons') . ':',
		'edit_item'         => __('Edit Tag', 'wp_coupons'),
		'update_item'       => __('Update Tag', 'wp_coupons'),
		'add_new_item'      => __('Add New Tag', 'wp_coupons'),
		'new_item_name'     => __('New Tag Name', 'wp_coupons'),
		'menu_name'         => __('Tags', 'wp_coupons'),
	);

	$args = array(
		'hierarchical'      => false,
		'labels'            => $labels,
		'show_ui'           => true,
		'show_admin_column' => true,
		'query_var'         => true,
		'has_archive'       => false
	);
	register_taxonomy('coupon-tag', array('coupon'), $args);
}
add_action('init', 'create_coupon_tag_tax');

//Add Expires Column
function wp_coupons_coupon_set_columns($columns) {
    //array_splice($columns, 5, 0, array('expires' => 'Expires'));
    $columns['expires'] = __('Expires', 'wp_coupons');
    return $columns;
}
add_filter('manage_coupon_posts_columns', 'wp_coupons_coupon_set_columns', 1);

//Populate Expires Column
function wp_coupons_coupon_columns($column, $post_id) {
	if($column == 'expires') {
		$expiration = get_post_meta($post_id, 'wp_coupons_expiration', true);
		if(!empty($expiration)) {
			echo $expiration;
		}
	}
}
add_action('manage_coupon_posts_custom_column' , 'wp_coupons_coupon_columns', 10, 2);

//Add Custom Capabilities to Admin Role
function wp_coupons_add_admin_capabilities() {
	$extras = get_option('wp_coupons_extra_options');

	if(empty($extras['wp_coupons_management_roles'])) {
		$role = get_role('administrator');
		$role->add_cap('read_coupon');
		$role->add_cap('read_private_coupons');
		$role->add_cap('edit_coupon');
		$role->add_cap('edit_coupons');
		$role->add_cap('edit_others_coupons');
		$role->add_cap('edit_published_coupons');
		$role->add_cap('publish_coupons');
		$role->add_cap('delete_others_coupons');
		$role->add_cap('delete_private_coupons');
		$role->add_cap('delete_published_coupons');

		$extras['wp_coupons_management_roles'] = array(0 => "administrator");
		update_option('wp_coupons_extra_options', $extras);
	}
}
add_action('init', 'wp_coupons_add_admin_capabilities');