<?php
$wp_coupons_display_options = get_option('wp_coupons_display_options');
global $wp_coupons_css_overrides;
$wp_coupons_css_overrides = false;

//wrapper output before our custom templates
function wp_coupons_output_content_wrapper () {
	echo "<div id='wp-coupons-outer-wrapper'><div id='wp-coupons-wrapper'>";
}
add_action( "wp_coupons_action_before_main_content" , "wp_coupons_output_content_wrapper" );

//wrapper output after our custom templates
function wp_coupons_output_content_wrapper_end () {
	echo "</div></div>";
}
add_action( "wp_coupons_action_after_main_content" , "wp_coupons_output_content_wrapper_end" );

//add open graph meta tags to archive
function wp_coupons_print_open_graph_meta() {

	//check for archive template
	if(is_post_type_archive('coupon') || is_tax('type')) {
		$display_options = get_option('wp_coupons_display_options');

		//facebook image
		if(!empty($display_options['wp_coupons_archive_facebook_image'])) {
			echo "<meta property=\"og:image\" content=\"" . $display_options['wp_coupons_archive_facebook_image'] . "\">\n";
		}

		//twitter image
		if(!empty($display_options['wp_coupons_archive_twitter_image'])) {
			echo "<meta property=\"twitter:image\" content=\"" . $display_options['wp_coupons_archive_twitter_image'] . "\">\n";
		}
	}
}
add_action('wp_head', 'wp_coupons_print_open_graph_meta', 1);

//set the number of coupons to fetch in the query
function wp_coupons_limit_posts($query) {
    if(is_admin() || !$query->is_main_query()) {
    	return;
    }
    if(is_post_type_archive('coupon') || is_tax('type')) {
    	//make sure coupon post type is include query
    	$query->set('post_type', array('coupon'));
    	$wp_coupons_display_options = get_option('wp_coupons_display_options');
    	if(!empty($wp_coupons_display_options['wp_coupons_archive_limit'])) {
    		$wp_coupons_archive_limit = $wp_coupons_display_options['wp_coupons_archive_limit'];
    	}
    	else {
    		$wp_coupons_archive_limit = 9;
    	}
        $query->set('posts_per_page', $wp_coupons_archive_limit);

        //archive sort order
        if(!empty($wp_coupons_display_options['wp_coupons_archive_sort_order'])) {
        	$query->set('orderby', $wp_coupons_display_options['wp_coupons_archive_sort_order']);

        	//set ascending order if sorting by title
        	if($wp_coupons_display_options['wp_coupons_archive_sort_order'] == 'title') {
        		$query->set('order', 'ASC');
        	}
        }

        return;
    }
}
add_action('pre_get_posts', 'wp_coupons_limit_posts', 99);

//add details banner to single coupon post content if custom template is disabled
function wp_coupons_filter_content($content) {
	$display_options = get_option('wp_coupons_display_options');
	if(is_singular('coupon') && (empty($display_options['wp_coupons_enable_single']) || $display_options['wp_coupons_enable_single'] != "1")) {
		$var = "<div style='overflow: hidden;'>";
			$var.= wp_coupons_banner_before();
			$var.= "<div class='wp-coupons-post-content'>";
				$var.= $content;
			$var.= "</div>";
		$var.= "</div>";
		return $var;
	} 
	return $content;
}
add_filter('the_content', 'wp_coupons_filter_content');

//pagination for our custom templates
function wp_coupons_pagination() {

	if(is_singular()) {
		return;
	}

	global $wp_query;

	//Stop execution if there's only 1 page
	if($wp_query->max_num_pages <= 1) {
		return;
	}

	$paged = get_query_var('paged') ? absint(get_query_var('paged')) : 1;
	$max   = intval($wp_query->max_num_pages);

	//Add current page to the array
	if($paged >= 1) {
		$links[] = $paged;
	}

	/**	Add the pages around the current page to the array */
	if($paged >= 3) {
		$links[] = $paged - 1;
		$links[] = $paged - 2;
	}

	if(($paged + 2) <= $max) {
		$links[] = $paged + 2;
		$links[] = $paged + 1;
	}

	echo "<div class='wp-coupons-navigation'>";
		echo "<ul>";

			//Previous Post Link 
			if(get_previous_posts_link()) {
				echo "<li>" . get_previous_posts_link("« " . __('Prev', 'wp_coupons')) . "</li>";
			}

			//Link to first page, plus ellipses if necessary
			if(!in_array(1, $links)) {
				$class = 1 == $paged ? ' class="active"' : '';
				echo "<li" . $class . "><a href='" . esc_url(get_pagenum_link(1)) . "'>1</a></li>";
				if(!in_array(2, $links)) {
					echo "<li>…</li>";
				}
			}

			//Link to current page, plus 2 pages in either direction if necessary
			sort($links);
			foreach((array) $links as $link) {
				$class = $paged == $link ? ' class="active"' : '';
				echo "<li" . $class . "><a href='" . esc_url(get_pagenum_link($link)) . "'>" . $link . "</a></li>";
			} 

			//Link to last page, plus ellipses if necessary
			if(!in_array($max, $links)) {
				if(!in_array($max - 1, $links)) {
					echo "<li>…</li>";
				}
				$class = $paged == $max ? ' class="active"' : '';
				echo "<li" . $class . "><a href='" . esc_url(get_pagenum_link($max)) . "'>" . $max . "</a></li>";
			}

			//Next Post Link
			if(get_next_posts_link()) {
				echo "<li>" . get_next_posts_link(__('Next', 'wp_coupons') . " »") . "</li>";
			}

		echo "</ul>";
	echo "</div>";
}

//coupon details banner for single coupon post
function wp_coupons_banner_before() {

	global $post;

	$wp_coupons_display = get_option('wp_coupons_display_options');
	$wp_coupons_styles = get_option('wp_coupons_styling_options');
	$wp_coupons_extra = get_option('wp_coupons_extra_options');

	$wp_coupons_call_to_action = get_post_meta($post->ID, 'wp_coupons_call_to_action', true);
	$wp_coupons_css_class = get_post_meta($post->ID, 'wp_coupons_css_class', true);
	$wp_coupons_discount_url = get_post_meta($post->ID, 'wp_coupons_discount_url', true);
	$wp_coupons_ctr_link = "";

	$var = "<style>
				.wp-coupons-banner {
					background: " . ($wp_coupons_styles['wp_coupons_panel_background_color'] ? $wp_coupons_styles['wp_coupons_panel_background_color'] : "") . ";
				}
				.wp-coupons-banner .wp-coupons-discount-percent {
					background: " . ($wp_coupons_styles['wp_coupons_discount_background_color'] ? $wp_coupons_styles['wp_coupons_discount_background_color'] : "") . ";
					color: " . ($wp_coupons_styles['wp_coupons_discount_text_color'] ? $wp_coupons_styles['wp_coupons_discount_text_color'] : "") . ";
					font-size: " . ($wp_coupons_styles['wp_coupons_discount_font_size'] ? $wp_coupons_styles['wp_coupons_discount_font_size'] : "") . ";
				}
				.wp-coupons-banner .wp-coupons-expiration {
					color: " . ($wp_coupons_styles['wp_coupons_expiration_text_color'] ? $wp_coupons_styles['wp_coupons_expiration_text_color'] : "") . ";
					font-size: " . ($wp_coupons_styles['wp_coupons_expiration_font_size'] ? $wp_coupons_styles['wp_coupons_expiration_font_size'] : "") . ";
				}
				.wp-coupons-banner .wp-coupons-discount-code {
					background: " . ($wp_coupons_styles['wp_coupons_discount_code_background_color'] ? $wp_coupons_styles['wp_coupons_discount_code_background_color'] : "") . ";
					color: " . ($wp_coupons_styles['wp_coupons_discount_code_text_color'] ? $wp_coupons_styles['wp_coupons_discount_code_text_color'] : "") . ";
					font-size: " . ($wp_coupons_styles['wp_coupons_discount_code_font_size'] ? $wp_coupons_styles['wp_coupons_discount_code_font_size'] : "") . ";
				}
				.wp-coupons-banner .wp-coupons-discount-code span {
					color: " . ($wp_coupons_styles['wp_coupons_discount_code_text_color'] ? $wp_coupons_styles['wp_coupons_discount_code_text_color'] : "") . ";
					border-color: " . ($wp_coupons_styles['wp_coupons_discount_code_text_color'] ? $wp_coupons_styles['wp_coupons_discount_code_text_color'] : "") . ";
				}
				body .wp-coupons-banner .coupon-title {
					font-size: " . ($wp_coupons_styles['wp_coupons_title_font_size'] ? $wp_coupons_styles['wp_coupons_title_font_size'] : "") . ";
				}
				.wp-coupons-banner .wp-coupons-discount-description {
					font-size: " . ($wp_coupons_styles['wp_coupons_description_font_size'] ? $wp_coupons_styles['wp_coupons_description_font_size'] : "") . ";
					line-height: " . ($wp_coupons_styles['wp_coupons_description_line_height'] ? $wp_coupons_styles['wp_coupons_description_line_height'] : "") . ";
				}
				body .wp-coupons-banner a.wp-coupons-button {
					background: " . ($wp_coupons_styles['wp_coupons_link_accent_color'] ? $wp_coupons_styles['wp_coupons_link_accent_color'] : "") . ";
					border-color: " . ($wp_coupons_styles['wp_coupons_link_accent_color'] ? $wp_coupons_styles['wp_coupons_link_accent_color'] : "") . ";
					font-size: " . ($wp_coupons_styles['wp_coupons_button_font_size'] ? $wp_coupons_styles['wp_coupons_button_font_size'] : "") . ";
				}
				body .wp-coupons-banner a.wp-coupons-button:hover {
					background: none;
					color: " . ($wp_coupons_styles['wp_coupons_link_accent_color_hover'] ? $wp_coupons_styles['wp_coupons_link_accent_color_hover'] : "") . ";
					border-color: " . ($wp_coupons_styles['wp_coupons_link_accent_color_hover'] ? $wp_coupons_styles['wp_coupons_link_accent_color_hover'] : "") . ";
				}
				body .wp-coupons-banner a.wp-coupons-breadcrumbs, #wp-coupons a.wp-coupons-breadcrumbs:visited {
					color: " . ($wp_coupons_styles['wp_coupons_link_accent_color'] ? $wp_coupons_styles['wp_coupons_link_accent_color'] : "") . ";
				}
				body .wp-coupons-banner a.wp-coupons-breadcrumbs:hover {
					color: " . ($wp_coupons_styles['wp_coupons_link_accent_color_hover'] ? $wp_coupons_styles['wp_coupons_link_accent_color_hover'] : "") . ";
				}
			</style>";
	$var.= '<div class="wp-coupons-banner wp-coupons-coupon-panel' . (!empty($wp_coupons_css_class) ? ' ' . $wp_coupons_css_class : '') . '">';

		if(!empty($wp_coupons_display['wp_coupons_single_template_image']) && $wp_coupons_display['wp_coupons_single_template_image'] == "1") {
			if(has_post_thumbnail()) {
				$var.= get_the_post_thumbnail($post->ID, 'full');                         
		    } 
		    else { 
		        $var.= "<img src='" . site_url() . "/wp-content/plugins/wp-coupons/images/sample-image.png' title='" . __('Sample Image', 'wp_coupons') . "' alt='" . __('Sample Image', 'wp_coupons') . "' />";
		    }
		}
		
		$var.= '<div class="wp-coupons-banner-content">';
			$var.= '<div class="wp-coupons-discounts">';

				$wp_coupons_discount_percent = get_post_meta($post->ID, "wp_coupons_discount_percent", true); 

				if(!empty($wp_coupons_discount_percent)) {
					$var.= '<div class="wp-coupons-discount-percent">' . $wp_coupons_discount_percent . '</div>';
				}

				$wp_coupons_discount_code = get_post_meta($post->ID, "wp_coupons_discount_code", true);

				if(!empty($wp_coupons_extra['wp_coupons_clipboard_js']) && $wp_coupons_extra['wp_coupons_clipboard_js'] == "1" && !empty($wp_coupons_discount_code)) {
					$wp_coupons_copy = "wp-coupons-copy";
				}
				else {
					$wp_coupons_copy = "";
				}

				if(!empty($wp_coupons_discount_code)) { 

					//click to reveal button
					if(!empty($wp_coupons_display['wp_coupons_click_to_reveal']) && $wp_coupons_display['wp_coupons_click_to_reveal'] == "1" && !empty($wp_coupons_discount_url)) {

						$wp_coupons_ctr_link = "wp-coupons-ctr-link"; 
						if(!empty($wp_coupons_display['wp_coupons_click_to_reveal_text'])) {
							$wp_coupons_ctr_text = $wp_coupons_display['wp_coupons_click_to_reveal_text'];
						}
						else {
							$wp_coupons_ctr_text = __('Click to Reveal', 'wp_coupons');
						}

						$var.= "<div class='wp-coupons-ctr-wrapper'>";
							$var.= "<div class='wp-coupons-discount-code wp-coupons-ctr " . $wp_coupons_copy . "' rel='" . $post->ID . "' value='" . $wp_coupons_discount_url . "' data-clipboard-text='" . $wp_coupons_discount_code . "'><i class='fa fa-tag'></i> " . $wp_coupons_ctr_text . "</div>";
						$var.= "</div>";

					} else {
						$var.= '<div class="wp-coupons-discount-code ' . $wp_coupons_copy . '" data-clipboard-text="' . $wp_coupons_discount_code . '">';
							$var.= "<i class='fa fa-tag'></i> " . $wp_coupons_discount_code;
							if(!empty($wp_coupons_extra['wp_coupons_clipboard_js']) && $wp_coupons_extra['wp_coupons_clipboard_js'] == "1") {
								$var.= "<span>" . __('Copy', 'wp_coupons') . "</span>";
							}
						$var.= '</div>';
					}
				} elseif(empty($wp_coupons_display['wp_coupons_hide_no_code_needed'])) {
					$var.= '<div class="wp-coupons-discount-code ' . $wp_coupons_copy . '" data-clipboard-text="' . $wp_coupons_discount_code . '">';
						if(!empty($wp_coupons_display['wp_coupons_no_code_needed_text'])) {
							$no_code_needed = $wp_coupons_display['wp_coupons_no_code_needed_text'];
						}
						else {
							$no_code_needed = __('No Code Needed', 'wp_coupons');
						}
						$var.= $no_code_needed;
					$var.= '</div>';
				}

			$var.= '</div>';

			$var.= '<div class="wp-coupons-banner-text">';

				$var.= '<h1 class="coupon-title">' . get_the_title() . '</h1>';

				$wp_coupons_discount_description = get_post_meta($post->ID, "wp_coupons_discount_description", true);

				if(!empty($wp_coupons_discount_description)) {
					$var.= '<div class="wp-coupons-discount-description">' . do_shortcode($wp_coupons_discount_description) . '</div>';
				}

				if(!empty($wp_coupons_display['wp_coupons_display_expiration']) && $wp_coupons_display['wp_coupons_display_expiration'] == "1") {
					$wp_coupons_expiration = get_post_meta($post->ID, "wp_coupons_expiration", true);
					if(!empty($wp_coupons_expiration)) {
						$var.= "<div class='wp-coupons-expiration'><i class='fa fa-clock-o'></i> " . __('Expires', 'wp_coupons') . " " . date_i18n("F j, Y", strtotime($wp_coupons_expiration)) . "</div>";
					}
				}

				$wp_coupons_discount_url = get_post_meta($post->ID, "wp_coupons_discount_url", true);

				if(!empty($wp_coupons_discount_url)) {

					$wp_coupons_nofollow = get_post_meta(get_the_ID(), 'wp_coupons_nofollow', true);
					if(!empty($wp_coupons_nofollow) && $wp_coupons_nofollow == "1") { $coupon_nofollow = "nofollow"; } else { $coupon_nofollow = ""; }


					if(!empty($wp_coupons_call_to_action)) {
						$coupon_cta = $wp_coupons_call_to_action;
					}
					elseif(!empty($wp_coupons_display['wp_coupons_call_to_action'])) {
						$coupon_cta = $wp_coupons_display['wp_coupons_call_to_action'];
					}
					else {
						$coupon_cta = __('Get This Deal', 'wp_coupons'); 
					}

					$var.= '<a href="' . $wp_coupons_discount_url . '" class="wp-coupons-button ' . $wp_coupons_ctr_link . '" target="_blank" rel="' . $coupon_nofollow . '">' . $coupon_cta . '</a>';
				}

			$var.= '</div>';
		$var.= '</div>';
	$var.= '</div>';

	if(!empty($wp_coupons_extra['wp_coupons_clipboard_js']) && $wp_coupons_extra['wp_coupons_clipboard_js'] == "1") {
		if(has_action('wp_footer', 'wp_coupons_output_clipboard_js') == false) {
			add_action('wp_footer', 'wp_coupons_output_clipboard_js');
		}
	}

	if(!empty($wp_coupons_display['wp_coupons_click_to_reveal'])) {
		if(has_action('wp_footer', 'wp_coupons_output_ctr_popup') == false) {
			add_action('wp_footer', 'wp_coupons_output_ctr_popup');
		}
	}

	return $var;
}

//schedule expire event
if(!wp_next_scheduled('wp_coupons_expire')) {
	wp_schedule_event(time(), 'daily', 'wp_coupons_expire');
}

//coupon expiration function
function wp_coupons_expire_coupons() {
	$today = date('m/d/Y');

	$args = array(
		'post_type' => 'coupon',
		'post_status' => 'publish',
		'meta_key' => 'wp_coupons_expiration',
		'posts_per_page' => -1
	);
	$query = new WP_Query($args);

	if($query->have_posts()) {
		while($query->have_posts()) {
			$query->the_post();
			$expiration_date = get_post_meta(get_the_ID(), 'wp_coupons_expiration', true);
			if(!empty($expiration_date)) {
				if(strtotime($expiration_date) < strtotime($today)) {
					$postdata = array(
						'ID' => get_the_ID(),
						'post_status' => 'draft'
					);
					wp_update_post($postdata);
				}
			}
		}
		wp_reset_postdata();
	}
}
add_action('wp_coupons_expire', 'wp_coupons_expire_coupons');

//Clipboard.js Action
function wp_coupons_output_clipboard_js() {

	//get necessary plugin settings
	$wp_coupons_display = get_option('wp_coupons_display_options');

	echo "<script>
		var copyCode = new Clipboard('.wp-coupons-copy', {
		    target: function(trigger) {
		        return trigger;
		    }
		});
		copyCode.on('success', function(event) {
			var spanCheck = event.trigger.getElementsByTagName('span').length;
		    if(spanCheck) {
		    	event.trigger.getElementsByTagName('span')[0].innerHTML = '" . __('Copied!', 'wp_coupons') . "';
		    	window.setTimeout(function() {
		       		event.trigger.getElementsByTagName('span')[0].innerHTML = '" . __('Copy', 'wp_coupons') . "';
		    	}, 2000);
		    }";

			if(!empty($wp_coupons_display['wp_coupons_click_to_reveal']) && $wp_coupons_display['wp_coupons_click_to_reveal'] == "1") {
				echo "
				if(event.trigger.classList.contains('wp-coupons-ctr')) {
					clickToReveal(event.trigger);
				}
				";
			}
		 
	echo "});
	</script>";
	
}
add_action("wp_coupons_clipboard_js" , "wp_coupons_output_clipboard_js", 1);

//Nav Dropdown JS
function wp_coupons_output_nav_dropdown_js() {

	echo "<script>
		(function ($) {
			$(document).ready(function(){
			    jQuery('.wp-coupons-nav-dropdown').change(function(){
			    	var selectedOptionURL = $('option:selected', this).attr('value');
			    	window.location.href = selectedOptionURL;
			    });
			});
		}(jQuery));
	</script>";
	
}

//Click to Reveal Action
function wp_coupons_output_ctr_popup() {

	//get necessary plugin settings
	$wp_coupons_display = get_option('wp_coupons_display_options');
	$wp_coupons_extra = get_option('wp_coupons_extra_options');

	if(!empty($_GET['wpcctr'])) {

		//get popup coupon details
		$wp_coupons_ctr_img = get_the_post_thumbnail_url($_GET['wpcctr'],'full');
		$wp_coupons_ctr_title = get_the_title($_GET['wpcctr']);
		$wp_coupons_ctr_discount_percent = get_post_meta($_GET['wpcctr'], "wp_coupons_discount_percent", true);
		$wp_coupons_ctr_discount_code = get_post_meta($_GET['wpcctr'], "wp_coupons_discount_code", true);
		$wp_coupons_ctr_discount_url = get_post_meta($_GET['wpcctr'], 'wp_coupons_discount_url', true);
		if(!empty($wp_coupons_extra['wp_coupons_clipboard_js']) && $wp_coupons_extra['wp_coupons_clipboard_js'] == "1") {
			$wp_coupons_ctr_copy = "wp-coupons-copy";
		}
		else {
			$wp_coupons_ctr_copy = "";
		}

		//print popup wrapper, container, content
		echo "<div id='wp-coupons-ctr-popup-wrapper'>";
			echo "<div style='display: table; height: 100%; width: 100%;'>";
				echo "<div style='display: table-cell; vertical-align: middle;'>";
					echo "<div id='wp-coupons-ctr-popup'>";

						//close popup
						echo "<div id='wp-coupons-ctr-popup-close'>x</div>";

						//coupon details
						if(!empty($wp_coupons_ctr_img)) {
							echo "<img id='wp-coupons-ctr-img' src='" . $wp_coupons_ctr_img . "' />";
						}
						if(!empty($wp_coupons_ctr_title)) {
							echo "<h2 id='wp-coupons-ctr-title'>" . $wp_coupons_ctr_title . "</h2>";
						}
						if(!empty($wp_coupons_ctr_discount_percent)) {
							echo "<div id='wp-coupons-ctr-discount-percent'>" . $wp_coupons_ctr_discount_percent . "</div>";
						}
						if(!empty($wp_coupons_ctr_discount_url)) {
							echo "<div id='wp-coupons-ctr-discount-url'>" . __('Copy and paste this code at', 'wp_coupons') . "<br />";
								echo "<a href='" . $wp_coupons_ctr_discount_url . "'>" . $wp_coupons_ctr_discount_url . "</a>";
							echo "</div>";
						}
						if(!empty($wp_coupons_ctr_discount_code)) {
							echo "<div id='wp-coupons-ctr-discount-code' class='" . $wp_coupons_ctr_copy . "' data-clipboard-text='" . $wp_coupons_ctr_discount_code . "'>";
								echo "<div>" . $wp_coupons_ctr_discount_code . "</div>";
								if(!empty($wp_coupons_extra['wp_coupons_clipboard_js']) && $wp_coupons_extra['wp_coupons_clipboard_js'] == "1") {
									echo "<span>" . __('Copy', 'wp_coupons') . "</span>";
								}
							echo "</div>";
						}

					echo "</div>";
				echo "</div>";
			echo "</div>";
		echo "</div>";
	}

	//craft popup hyperlink
	$wpcctr_href = site_url() . esc_url(remove_query_arg('wpcctr'));
	$wpcctr_href = add_query_arg('wpcctr', '', $wpcctr_href);

	//ctr behavior specific javascript
	if(!empty($wp_coupons_display['wp_coupons_click_to_reveal_behavior']) && $wp_coupons_display['wp_coupons_click_to_reveal_behavior'] == "popup") {
		$wp_coupons_ctr_js = "
			window.open('" . $wpcctr_href . "=' + postID, '_self');
		";
	} 
	else {
		$wp_coupons_ctr_js = "
			window.open('" . $wpcctr_href . "=' + postID, '_blank');
			window.open(discountURL, '_self');
		";
	} 

	//print ctr javascript
	echo "<script type='text/javascript'>
		function clickToReveal(item) {
			var postID = jQuery(item).attr('rel');
			var discountURL = jQuery(item).attr('value');
			clickToRevealPush(discountURL, postID);
		}

		function clickToRevealPush(discountURL, postID) {
			" . $wp_coupons_ctr_js . "
		}

		jQuery(document).ready(function() {

			jQuery('.wp-coupons-ctr').click(function(item){
				if(!jQuery(this).hasClass('wp-coupons-copy')) {
					clickToReveal(item.target);
				}
			});
			jQuery('.wp-coupons-ctr-link').click(function(e){
				if(!jQuery(this).hasClass('wp-coupons-copy')) {
					e.preventDefault();
					clickToReveal(jQuery(this).closest('.wp-coupons-coupon-panel').find('.wp-coupons-discount-code.wp-coupons-ctr'));
				}
			});

			jQuery('#wp-coupons-ctr-popup-wrapper').click(function(e){
				if(e.target.id != 'wp-coupons-ctr-popup' && !jQuery('#wp-coupons-ctr-popup').find(e.target).length) {
			        jQuery('#wp-coupons-ctr-popup-wrapper').hide();
			    }
			});
			jQuery('#wp-coupons-ctr-popup-close').click(function(){
				jQuery('#wp-coupons-ctr-popup-wrapper').hide();
			});
		});
	</script>";
}
add_action("wp_coupons_click_to_reveal" , "wp_coupons_output_ctr_popup", 1);

function wp_coupons_exclude_from_archive($query) {
	if(!is_admin() && (is_post_type_archive('coupon') || is_tax('type'))) {
		$current_meta = $query->get('meta_query');
	    $custom_meta = array(
	        'key' => 'wp_coupons_exclude_archive',
	        'type' => 'BINARY',
	        'compare' => 'NOT EXISTS'
	    );
	    if(!empty($current_meta)) {
	    	$meta_query = $current_meta[] = $custom_meta;
	    }
	    else {
			$meta_query = $custom_meta;
	    }
	    $query->set('meta_query', array($meta_query));
    }
}

add_action('pre_get_posts','wp_coupons_exclude_from_archive');


//Tag Subnav
if(!empty($wp_coupons_display_options['wp_coupons_enable_subnav']) && $wp_coupons_display_options['wp_coupons_enable_subnav'] == "1") {
	add_action('init', 'wp_coupons_tag_subnav_rewrite');
}
function wp_coupons_tag_subnav_rewrite() {

	global $wp_coupons_display_options;

	//need to replace 'demo' with the users given archive slug if available or coupon if not
	$archive_slug = "all-" . (!empty($wp_coupons_display_options['wp_coupons_archive_slug']) ? $wp_coupons_display_options['wp_coupons_archive_slug'] : "coupons");

	//Rewrite Tag URL
    add_rewrite_rule('^' . $archive_slug . '/([^/]*)/([^/]*)/?$', 'index.php?type=$matches[1]&coupon-tag=$matches[2]', 'top');

    //Rewrite Tag URL w/ Pagination
    add_rewrite_rule('^' . $archive_slug . '/([^/]*)/([^/]*)/page/([0-9]+)?$', 'index.php?type=$matches[1]&coupon-tag=$matches[2]&paged=$matches[3]', 'top');
}

//related coupons
function wp_coupons_related_coupons($id) {

	global $wp_coupons_display_options;
	$wp_coupons_extra = get_option('wp_coupons_extra_options');

	$var = "";

	$var.= wp_coupons_css_overrides();

	$customTaxonomyTerms = wp_get_object_terms($id, 'your_taxonomy', array('fields' => 'ids'));

	//query arguments
	$args = array(
	    'post_type' => 'coupon',
	    'post_status' => 'publish',
	    'posts_per_page' => 3,
	    'orderby' => 'rand',
	    'post__not_in' => array ($id),
	);

	//the query
	$relatedPosts = new WP_Query($args);

	$j = 0;

	//loop through query
	if($relatedPosts->have_posts()){

		$var.= "<div class='wp-coupons wp-coupons-related-coupons'>";
			$var.= "<h2>" . (!empty($wp_coupons_display_options['wp_coupons_related_coupons_text']) ? $wp_coupons_display_options['wp_coupons_related_coupons_text'] : __('Related Coupons', 'wp_coupons')) . "</h2>";
		    while($relatedPosts->have_posts()) { 
		        $relatedPosts->the_post();
		        $j++;

				if(($j == 1) || (($j-1) % 3 == 0)) {
					$var.= "<div class='coupon-row'>";
				}

				$var.= "<div class='wp-coupons-coupon " . (($j % 3 == 0) ? "third" : "") . (($j % 2 == 0) ? "second" : "") . "'>";

					$var.= wp_coupons_coupon_panel(get_the_ID());
					
				$var.= "</div>";

				if(($j % 3 == 0) || ($j == $relatedPosts->post_count)) {
					$var.= "</div>";
				}
			}
	    $var.= "</div>";
	}else{
	    //no posts found
	}

	//restore original post data
	wp_reset_postdata();

	if(!empty($wp_coupons_extra['wp_coupons_clipboard_js']) && $wp_coupons_extra['wp_coupons_clipboard_js'] == "1") {
		if(has_action('wp_footer', 'wp_coupons_output_clipboard_js') == false) {
			add_action('wp_footer', 'wp_coupons_output_clipboard_js');
		}
	}

	if(!empty($wp_coupons_display_options['wp_coupons_click_to_reveal'])) {
		if(has_action('wp_footer', 'wp_coupons_output_ctr_popup') == false) {
			add_action('wp_footer', 'wp_coupons_output_ctr_popup');
		}
	}

	return $var;
}

function wp_coupons_after_post_content($content){
	global $wp_coupons_display_options;

	if(!in_the_loop() || empty($wp_coupons_display_options['wp_coupons_display_related_coupons']) || !empty($wp_coupons_display_options['wp_coupons_related_coupons_hook']) || (is_singular('coupon') && !empty($wp_coupons_display_options['wp_coupons_enable_single']) && $wp_coupons_display_options['wp_coupons_enable_single'] == "1")) {
		return $content;
	}

	if(!empty($wp_coupons_display_options['wp_coupons_related_coupons_locations'])) {
		if(in_array(get_post_type(), $wp_coupons_display_options['wp_coupons_related_coupons_locations'])) {  
		    $content.= wp_coupons_related_coupons(get_the_ID());
		}
	}

    return $content;
}
add_filter("the_content", "wp_coupons_after_post_content");

function wp_coupons_related_posts_action() {
	global $wp_coupons_display_options;
	if(in_the_loop() && !empty($wp_coupons_display_options['wp_coupons_display_related_coupons']) && (!is_singular('coupon') || empty($wp_coupons_display_options['wp_coupons_enable_single']))) {
		if(!empty($wp_coupons_display_options['wp_coupons_related_coupons_locations'])) {
			if(in_array(get_post_type(), $wp_coupons_display_options['wp_coupons_related_coupons_locations'])) {
				echo wp_coupons_related_coupons(get_the_ID());
			}
		}
	}
}
if(!empty($wp_coupons_display_options['wp_coupons_related_coupons_hook'])) {
	$priority = 10;
	if(!empty($wp_coupons_display_options['wp_coupons_related_coupons_hook_priority']) && is_numeric($wp_coupons_display_options['wp_coupons_related_coupons_hook_priority'])) {
		$priority = $wp_coupons_display_options['wp_coupons_related_coupons_hook_priority'];
	}
	add_action($wp_coupons_display_options['wp_coupons_related_coupons_hook'], "wp_coupons_related_posts_action", $priority);
}



//css overrides
function wp_coupons_css_overrides() {

	global $wp_coupons_css_overrides;

	if(!$wp_coupons_css_overrides) {

		$wp_coupons_css_overrides = true;

		$wp_coupons_display = get_option('wp_coupons_display_options');
		$wp_coupons_styles = get_option('wp_coupons_styling_options');

		$var = "<style>
			/*Archive Template Only*/
			#wp-coupons-outer-wrapper {
				padding-left: " . (!empty($wp_coupons_display['wp_coupons_wrapper_padding']) ? $wp_coupons_display['wp_coupons_wrapper_padding'] : "") . ";
				padding-right: " . (!empty($wp_coupons_display['wp_coupons_wrapper_padding']) ? $wp_coupons_display['wp_coupons_wrapper_padding'] : "") . ";
			}
			#wp-coupons-wrapper {
				max-width: " . (!empty($wp_coupons_display['wp_coupons_wrapper_width']) ? $wp_coupons_display['wp_coupons_wrapper_width'] : "") . ";
			}
			/*Navigation*/
			body .wp-coupons-nav a, body .wp-coupons-nav a:visited {
				font-size: " . (!empty($wp_coupons_styles['wp_coupons_nav_font_size']) ? $wp_coupons_styles['wp_coupons_nav_font_size'] : "") . ";
				color: " . (!empty($wp_coupons_styles['wp_coupons_link_accent_color']) ? $wp_coupons_styles['wp_coupons_link_accent_color'] : "") . ";
			}
			body .wp-coupons-nav a:hover, body .wp-coupons-nav a.wp-coupons-nav-selected {
				color: " . (!empty($wp_coupons_styles['wp_coupons_link_accent_color_hover']) ? $wp_coupons_styles['wp_coupons_link_accent_color_hover'] : "") . ";
			}
			body .wp-coupons-subnav a, body .wp-coupons-subnav a:visited {
				font-size: " . (!empty($wp_coupons_styles['wp_coupons_subnav_font_size']) ? $wp_coupons_styles['wp_coupons_subnav_font_size'] : "") . ";
				color: " . (!empty($wp_coupons_styles['wp_coupons_link_accent_color']) ? $wp_coupons_styles['wp_coupons_link_accent_color'] : "") . ";
				border-color: " . (!empty($wp_coupons_styles['wp_coupons_link_accent_color']) ? $wp_coupons_styles['wp_coupons_link_accent_color'] : "") . ";
			}
			body .wp-coupons-subnav a.active, body .wp-coupons-subnav a:hover {
				color: " . (!empty($wp_coupons_styles['wp_coupons_link_accent_color_hover']) ? $wp_coupons_styles['wp_coupons_link_accent_color_hover'] : "") . ";
				border-color: " . (!empty($wp_coupons_styles['wp_coupons_link_accent_color_hover']) ? $wp_coupons_styles['wp_coupons_link_accent_color_hover'] : "") . ";
			}
			/*Coupon Panel*/
			.wp-coupons-coupon-panel {
				background: " . (!empty($wp_coupons_styles['wp_coupons_panel_background_color']) ? $wp_coupons_styles['wp_coupons_panel_background_color'] : "") . ";
			}
			.wp-coupons-coupon-panel .wp-coupons-discount-percent {
				background: " . (!empty($wp_coupons_styles['wp_coupons_discount_background_color']) ? $wp_coupons_styles['wp_coupons_discount_background_color'] : "") . ";
				color: " . (!empty($wp_coupons_styles['wp_coupons_discount_text_color']) ? $wp_coupons_styles['wp_coupons_discount_text_color'] : "") . ";
				font-size: " . (!empty($wp_coupons_styles['wp_coupons_discount_font_size']) ? $wp_coupons_styles['wp_coupons_discount_font_size'] : "") . ";
			}
			.wp-coupons-coupon-panel .wp-coupons-expiration {
				color: " . (!empty($wp_coupons_styles['wp_coupons_expiration_text_color']) ? $wp_coupons_styles['wp_coupons_expiration_text_color'] : "") . ";
				font-size: " . (!empty($wp_coupons_styles['wp_coupons_expiration_font_size']) ? $wp_coupons_styles['wp_coupons_expiration_font_size'] : "") . ";
			}
			 .wp-coupons-coupon-panel .wp-coupons-discount-code {
				background: " . (!empty($wp_coupons_styles['wp_coupons_discount_code_background_color']) ? $wp_coupons_styles['wp_coupons_discount_code_background_color'] : "") . ";
				color: " . (!empty($wp_coupons_styles['wp_coupons_discount_code_text_color']) ? $wp_coupons_styles['wp_coupons_discount_code_text_color'] : "") . ";
				font-size: " . (!empty($wp_coupons_styles['wp_coupons_discount_code_font_size']) ? $wp_coupons_styles['wp_coupons_discount_code_font_size'] : "") . ";
			}
			.wp-coupons-coupon-panel .wp-coupons-discount-code span {
				color: " . (!empty($wp_coupons_styles['wp_coupons_discount_code_text_color']) ? $wp_coupons_styles['wp_coupons_discount_code_text_color'] : "") . ";
				border-color: " . (!empty($wp_coupons_styles['wp_coupons_discount_code_text_color']) ? $wp_coupons_styles['wp_coupons_discount_code_text_color'] : "") . ";
			}
			.wp-coupons-coupon-panel .wp-coupons-ctr:before {
				border-color: " . (!empty($wp_coupons_styles['wp_coupons_ctr_folded_corner_color']) ? $wp_coupons_styles['wp_coupons_ctr_folded_corner_color'] . " transparent" : "") . ";
			}
			.wp-coupons-coupon-panel .wp-coupons-ctr:after {
				border-color: " . (!empty($wp_coupons_styles['wp_coupons_discount_code_background_color']) ? $wp_coupons_styles['wp_coupons_discount_code_background_color'] : "") . ";
			}
			.wp-coupons-coupon-panel .coupon-separator {
				border-color: " . (!empty($wp_coupons_styles['wp_coupons_separator_color']) ? $wp_coupons_styles['wp_coupons_separator_color'] : "") . ";
			}
			.wp-coupons-coupon-panel .coupon-title {
				font-size: " . (!empty($wp_coupons_styles['wp_coupons_title_font_size']) ? $wp_coupons_styles['wp_coupons_title_font_size'] : "") . ";
			}
			.wp-coupons-coupon-panel .coupon-title, .wp-coupons-coupon-panel .coupon-title:visited, .wp-coupons-coupon-panel .coupon-link, .wp-coupons-coupon-panel .coupon-link:visited, .wp-coupons-banner .coupon-title {
				color: " . (!empty($wp_coupons_styles['wp_coupons_link_accent_color']) ? $wp_coupons_styles['wp_coupons_link_accent_color'] : "") . ";
			}
			.wp-coupons-coupon-panel .coupon-title:hover, .wp-coupons-coupon-panel .coupon-link:hover {
				color: " . (!empty($wp_coupons_styles['wp_coupons_link_accent_color_hover']) ? $wp_coupons_styles['wp_coupons_link_accent_color_hover'] : "") . ";
			}
			.wp-coupons-coupon-panel .coupon-description {
				font-size: " . (!empty($wp_coupons_styles['wp_coupons_description_font_size']) ? $wp_coupons_styles['wp_coupons_description_font_size'] : "") . ";
				line-height: " . (!empty($wp_coupons_styles['wp_coupons_description_line_height']) ? $wp_coupons_styles['wp_coupons_description_line_height'] : "") . ";
				min-height: " . (!empty($wp_coupons_display['wp_coupons_description_height']) ? $wp_coupons_display['wp_coupons_description_height'] : "") . ";
				max-height: " . (!empty($wp_coupons_display['wp_coupons_description_height']) ? $wp_coupons_display['wp_coupons_description_height'] : "") . ";
			}
			.wp-coupons-coupon-panel .coupon-type, .wp-coupons-coupon-panel .coupon-type:hover, .wp-coupons-coupon-panel .coupon-type:visited {
				color: " . (!empty($wp_coupons_styles['wp_coupons_type_text_color']) ? $wp_coupons_styles['wp_coupons_type_text_color'] : "") . ";
				font-size: " . (!empty($wp_coupons_styles['wp_coupons_type_font_size']) ? $wp_coupons_styles['wp_coupons_type_font_size'] : "") . ";
			}
			.wp-coupons-coupon-panel a.coupon-link {
				font-size: " . (!empty($wp_coupons_styles['wp_coupons_cta_font_size']) ? $wp_coupons_styles['wp_coupons_cta_font_size'] : "") . ";
			}
			/*Pagination*/
			body .wp-coupons-navigation .page-numbers, body .wp-coupons-navigation .page-numbers:visited {
				background-color: " . (!empty($wp_coupons_styles['wp_coupons_link_accent_color']) ? $wp_coupons_styles['wp_coupons_link_accent_color'] : "") . ";
			}
			body .wp-coupons-navigation .page-numbers.current, body .wp-coupons-navigation .page-numbers:hover {
				background-color: " . (!empty($wp_coupons_styles['wp_coupons_link_accent_color_hover']) ? $wp_coupons_styles['wp_coupons_link_accent_color_hover'] : "") . ";
			}
			/*Click to Reveal Popup*/
			#wp-coupons-ctr-popup #wp-coupons-ctr-discount-code span {
				background: " . (!empty($wp_coupons_styles['wp_coupons_discount_code_background_color']) ? $wp_coupons_styles['wp_coupons_discount_code_background_color'] : "") . ";
				color: " . (!empty($wp_coupons_styles['wp_coupons_discount_code_text_color']) ? $wp_coupons_styles['wp_coupons_discount_code_text_color'] : "") . ";
			}
			#wp-coupons-ctr-popup #wp-coupons-ctr-discount-url a {
				color: " . (!empty($wp_coupons_styles['wp_coupons_link_accent_color']) ? $wp_coupons_styles['wp_coupons_link_accent_color'] : "") . ";
			}
			#wp-coupons-ctr-popup #wp-coupons-ctr-discount-url a:hover {
				color: " . (!empty($wp_coupons_styles['wp_coupons_link_accent_color_hover']) ? $wp_coupons_styles['wp_coupons_link_accent_color_hover'] : "") . ";
			}
			/*Buttons*/
			body a.wp-coupons-button {
				background: " . (!empty($wp_coupons_styles['wp_coupons_link_accent_color']) ? $wp_coupons_styles['wp_coupons_link_accent_color'] : "") . ";
				border-color: " . (!empty($wp_coupons_styles['wp_coupons_link_accent_color']) ? $wp_coupons_styles['wp_coupons_link_accent_color'] : "") . ";
				font-size: " . (!empty($wp_coupons_styles['wp_coupons_button_font_size']) ? $wp_coupons_styles['wp_coupons_button_font_size'] : "") . ";
			}
			body a.wp-coupons-button:hover {
				color: " . (!empty($wp_coupons_styles['wp_coupons_link_accent_color_hover']) ? $wp_coupons_styles['wp_coupons_link_accent_color_hover'] : "") . ";
				border-color: " . (!empty($wp_coupons_styles['wp_coupons_link_accent_color_hover']) ? $wp_coupons_styles['wp_coupons_link_accent_color_hover'] : "") . ";
			}
			@media(min-width: 794px) {
				.wp-coupons-coupon.list.compact .wp-coupons-coupon-panel .coupon-link, .wp-coupons-coupon.list.minimal .wp-coupons-coupon-panel .coupon-link {
					font-size: " . (!empty($wp_coupons_styles['wp_coupons_description_font_size']) ? $wp_coupons_styles['wp_coupons_description_font_size'] : "") . ";
					line-height: " . (!empty($wp_coupons_styles['wp_coupons_description_line_height']) ? $wp_coupons_styles['wp_coupons_description_line_height'] : "") . ";
				}
			}
		</style>";
		return $var;
	}
}

//coupon panel
function wp_coupons_coupon_panel($id, $params = array()) {

	$wp_coupons_display = get_option('wp_coupons_display_options');
	$wp_coupons_extra = get_option('wp_coupons_extra_options');

	$wp_coupons_call_to_action = get_post_meta($id, 'wp_coupons_call_to_action', true);
	if(!empty($params['class'])) {
		$wp_coupons_css_class = $params['class'];
	}
	else {
		$wp_coupons_css_class = get_post_meta($id, 'wp_coupons_css_class', true);
	}
	$wp_coupons_discount_url = get_post_meta($id, 'wp_coupons_discount_url', true);
	$wp_coupons_ctr_link = "";

	$var = "<div class='wp-coupons-coupon-panel" . (!empty($params['template']) ? ' ' . $params['template'] : '') . (!empty($wp_coupons_css_class) ? ' ' . $wp_coupons_css_class : '') . "'>";

		$var.= "<div class='coupon-panel-image-wrapper' style='position: relative; overflow: hidden;'>";
					
			//coupon discount
			$wp_coupons_discount_percent = get_post_meta($id, "wp_coupons_discount_percent", true);
			if(!empty($wp_coupons_discount_percent)) {
				$var.= "<div class='wp-coupons-discount-percent'>" . $wp_coupons_discount_percent . "</div>";
			}

			//coupon code
			if(!empty($wp_coupons_display['wp_coupons_display_discount_codes']) && $wp_coupons_display['wp_coupons_display_discount_codes'] == "1") {
				$wp_coupons_discount_code = get_post_meta($id, "wp_coupons_discount_code", true);
				if(!empty($wp_coupons_discount_code)) {

					if(!empty($wp_coupons_extra['wp_coupons_clipboard_js']) && $wp_coupons_extra['wp_coupons_clipboard_js'] == "1") {
						$wp_coupons_copy = "wp-coupons-copy";
					}
					else {
						$wp_coupons_copy = "";
					}

					//click to reveal button
					if(!empty($wp_coupons_display['wp_coupons_click_to_reveal']) && $wp_coupons_display['wp_coupons_click_to_reveal'] == "1" && !empty($wp_coupons_discount_url)) {

						$wp_coupons_ctr_link = "wp-coupons-ctr-link"; 
						if(!empty($wp_coupons_display['wp_coupons_click_to_reveal_text'])) {
							$wp_coupons_ctr_text = $wp_coupons_display['wp_coupons_click_to_reveal_text'];
						}
						else {
							$wp_coupons_ctr_text = __('Click to Reveal', 'wp_coupons');
						}

						$var.= "<div class='wp-coupons-ctr-wrapper'>";
							$var.= "<div class='wp-coupons-discount-code wp-coupons-ctr " . $wp_coupons_copy . "' rel='" . $id . "' value='" . $wp_coupons_discount_url . "' data-clipboard-text='" . $wp_coupons_discount_code . "'><i class='fa fa-tag'></i> " . $wp_coupons_ctr_text . "</div>";
						$var.= "</div>";

					} else {

						$var.= "<div class='wp-coupons-discount-code " . $wp_coupons_copy . "' data-clipboard-text='" . $wp_coupons_discount_code . "'><i class='fa fa-tag'></i> " . $wp_coupons_discount_code;

							if(!empty($wp_coupons_extra['wp_coupons_clipboard_js']) && $wp_coupons_extra['wp_coupons_clipboard_js'] == "1") {
								$var.= "<span>" . __('Copy', 'wp_coupons') . "</span>";
							}

						$var.= "</div>";
					}
				} 
				elseif(empty($wp_coupons_display['wp_coupons_hide_no_code_needed'])) {
					$var.= "<div class='wp-coupons-discount-code'>";
						if(!empty($wp_coupons_display['wp_coupons_no_code_needed_text'])) {
							$no_code_needed = $wp_coupons_display['wp_coupons_no_code_needed_text'];
						}
						else {
							$no_code_needed = __('No Code Needed', 'wp_coupons');
						}
						$var.=  $no_code_needed;
					$var.=  "</div>";
				}
			}

			if(isset($params['direct_link'])) {
				$wp_coupons_direct_link = filter_var($params['direct_link'], FILTER_VALIDATE_BOOLEAN);
			}
			else {
				$wp_coupons_direct_link = get_post_meta($id, 'wp_coupons_direct_link', true);
			}

			//check if direct links are set and if there is a discount url available
			if(((!empty($wp_coupons_direct_link) && $wp_coupons_direct_link == "1") || (!empty($wp_coupons_extra['wp_coupons_direct_links']) && $wp_coupons_extra['wp_coupons_direct_links'] == "1")) && !empty($wp_coupons_discount_url)) {
				$coupon_permalink = $wp_coupons_discount_url;
				if(!empty($wp_coupons_extra['wp_coupons_direct_links_target'])) {
					$coupon_permalink_target = $wp_coupons_extra['wp_coupons_direct_links_target'];
				}
				else {
					$coupon_permalink_target = "_blank";
				}
				//check if nofollow is set for coupon post
				if(isset($params['nofollow'])) {
					$wp_coupons_nofollow = filter_var($params['nofollow'], FILTER_VALIDATE_BOOLEAN);
				}
				else {
					$wp_coupons_nofollow = get_post_meta($id, 'wp_coupons_nofollow', true);
				}
				if(!empty($wp_coupons_nofollow) && $wp_coupons_nofollow == "1") {
					$coupon_permalink_rel = "nofollow";
				}
				else {
					$coupon_permalink_rel = "";
				}
			}
			else {
				$coupon_permalink = get_the_permalink();
				$coupon_permalink_target = "_self";
				$coupon_permalink_rel = "";
			}

			//coupon featured image
			$var.= "<a href='" . ($coupon_permalink ? $coupon_permalink : "") . "' class='" . $wp_coupons_ctr_link . "' target='" . $coupon_permalink_target . "' title='" . get_the_title() . "' rel='" . $coupon_permalink_rel . "'>";
				if(has_post_thumbnail()) {
					$var.= get_the_post_thumbnail($id, 'full');                         
		        } else {
		        	$var.= "<img src='" . site_url() . "/wp-content/plugins/wp-coupons/images/sample-image.png' title='" . __('Sample Image', 'wp_coupons') . "' alt='" . __('Sample Image', 'wp_coupons') . "' />";
		        }
		    $var.= "</a>";
		$var.= "</div>";

		//coupon content
		$var.= "<div class='wp-coupons-coupon-content' style='padding: 0px 25px 10px 25px; overflow: hidden;'>";

			$var.= "<a href='" . ($coupon_permalink ? $coupon_permalink : "") . "' class='" . $wp_coupons_ctr_link . "' target='" . $coupon_permalink_target . "' title='" . get_the_title() . "' rel='" . $coupon_permalink_rel . "'>";
				$var.= "<h2 class='coupon-title'>" . get_the_title() . "</h2>";
			$var.= "</a>";
		     
			$var.= "<div class='coupon-description'>";
				$wp_coupons_discount_description = get_post_meta($id, "wp_coupons_discount_description", true);
				if(!empty($wp_coupons_discount_description)) {
		        	$var.= do_shortcode($wp_coupons_discount_description);
		        }
			$var.= "</div>";

			//expiration date
			if(!empty($wp_coupons_display['wp_coupons_display_expiration']) && $wp_coupons_display['wp_coupons_display_expiration'] == "1") {
				$var.= "<div class='wp-coupons-expiration'>";
					$wp_coupons_expiration = get_post_meta($id, "wp_coupons_expiration", true);
					if(!empty($wp_coupons_expiration)) {
						$var.= "<i class='fa fa-clock-o'></i> " . __('Expires', 'wp_coupons') . " " . date_i18n("F j, Y", strtotime($wp_coupons_expiration));
					}
				$var.= "</div>";
			}

			if(!empty($wp_coupons_call_to_action)) {
				$coupon_cta = $wp_coupons_call_to_action;
			}
			elseif(!empty($wp_coupons_display['wp_coupons_call_to_action'])) {
				$coupon_cta = $wp_coupons_display['wp_coupons_call_to_action'];
			}
			else {
				$coupon_cta = __('Get This Deal', 'wp_coupons');
			}

			if(!empty($params['button']) && $params['button'] != false) {
				$var.= "<a href='" . ($coupon_permalink ? $coupon_permalink : "") . "' title='' class='wp-coupons-button " . $wp_coupons_ctr_link . "' target='" . $coupon_permalink_target . "' rel='" . $coupon_permalink_rel . "'>" . $coupon_cta . "</a>";
			}
			else {

				$var.= "<hr class='coupon-separator' />";

				$var.= "<div class='wp-coupons-type-cta-container'>";

					$var.= "<a href='" . ($coupon_permalink ? $coupon_permalink : "") . "' target='" . $coupon_permalink_target . "' rel='" . $coupon_permalink_rel . "' class='coupon-link " . $wp_coupons_ctr_link . "'>" . $coupon_cta . " <i class='fa fa-arrow-right'></i></a>";
				
					if(empty($wp_coupons_display['wp_coupons_hide_coupon_type_tags'])) {
						$coupon_types = wp_get_post_terms($id, 'type');
						if(!empty($coupon_types[0])) {
							$var.= "<a href='" . get_term_link($coupon_types[0]) . "' title='" . $coupon_types[0]->name . "' class='coupon-type'>" . $coupon_types[0]->name . "</a>";
						}
					}

				$var.= "</div>";
			}




		$var.= "</div>";
	$var.= "</div>";

	return $var;
}


/***********************************************************************
* EDD License Functions
***********************************************************************/
function wp_coupons_edd_activate_license() {

	//listen for our activate button to be clicked
	if(isset($_POST['wp_coupons_edd_license_activate'])) {

		//run a quick security check
	 	if(!check_admin_referer('wp_coupons_edd_nonce', 'wp_coupons_edd_nonce')) {
			return; // get out if we didn't click the Activate button
	 	}

		//retrieve the license from the database
		$license = trim(get_option('wp_coupons_edd_license_key'));

		//data to send in our API request
		$api_params = array(
			'edd_action'=> 'activate_license',
			'license' 	=> $license,
			'item_name' => urlencode(WP_COUPONS_ITEM_NAME), // the name of our product in EDD
			'url'       => home_url()
		);

		//Call the custom API.
		$response = wp_remote_post(WP_COUPONS_STORE_URL, array('timeout' => 15, 'sslverify' => false, 'body' => $api_params));

		//make sure the response came back okay
		if(is_wp_error($response)) {
			return false;
		}

		//decode the license data
		$license_data = json_decode(wp_remote_retrieve_body($response));

		//$license_data->license will be either "valid" or "invalid"
		update_option('wp_coupons_edd_license_status', $license_data->license);
	}
}
add_action('admin_init', 'wp_coupons_edd_activate_license');

function wp_coupons_edd_deactivate_license() {

	// listen for our activate button to be clicked
	if(isset($_POST['wp_coupons_edd_license_deactivate'])) {

		// run a quick security check
	 	if(!check_admin_referer('wp_coupons_edd_nonce', 'wp_coupons_edd_nonce')) {
			return; // get out if we didn't click the Activate button
	 	}

		// retrieve the license from the database
		$license = trim(get_option('wp_coupons_edd_license_key'));

		// data to send in our API request
		$api_params = array(
			'edd_action'=> 'deactivate_license',
			'license' 	=> $license,
			'item_name' => urlencode(WP_COUPONS_ITEM_NAME), // the name of our product in EDD
			'url'       => home_url()
		);

		// Call the custom API.
		$response = wp_remote_post(WP_COUPONS_STORE_URL, array('timeout' => 15, 'sslverify' => false, 'body' => $api_params));

		// make sure the response came back okay
		if(is_wp_error($response)) {
			return false;
		}

		// decode the license data
		$license_data = json_decode(wp_remote_retrieve_body($response));

		// $license_data->license will be either "deactivated" or "failed"
		if($license_data->license == 'deactivated') {
			delete_option('wp_coupons_edd_license_status');
		}
	}
}
add_action('admin_init', 'wp_coupons_edd_deactivate_license');

function wp_coupons_edd_check_license() {

	global $wp_version;

	$license = trim(get_option('wp_coupons_edd_license_key'));

	$api_params = array(
		'edd_action' => 'check_license',
		'license' => $license,
		'item_name' => urlencode(WP_COUPONS_ITEM_NAME),
		'url'       => home_url()
	);

	// Call the custom API.
	$response = wp_remote_post(WP_COUPONS_STORE_URL, array('timeout' => 15, 'sslverify' => false, 'body' => $api_params));

	if(is_wp_error($response)) {
		return false;
	}

	$license_data = json_decode(wp_remote_retrieve_body($response));

	if($license_data->license == 'valid') {
		update_option('wp_coupons_edd_license_status', "valid");
	}
	else {
		update_option('wp_coupons_edd_license_status', "invalid");
	}
	
	return($license_data);
}