<?php
//Add Coupon Details Meta Box to Custom Post Type
function wp_coupons_add_meta_box() {
    add_meta_box('wp_coupons_details', 'WP Coupons ' . __('Details', 'wp_coupons'), 'wp_coupons_load_meta_box', 'coupon', 'normal', 'high');
}
add_action( 'add_meta_boxes', 'wp_coupons_add_meta_box', 1);

//Load HTML for Coupon Details Meta Box
function wp_coupons_load_meta_box() {

	global $post;

	echo '<style>
		#wp_coupons_details input[type="text"], #wp_coupons_details textarea {
			margin-bottom: 5px;
		}
	</style>';
	
	//Noncename needed to verify where the data originated
	echo '<input type="hidden" name="wp_coupons_meta_noncename" id="wp_coupons_meta_noncename" value="' . wp_create_nonce( plugin_basename(__FILE__) ) . '" />';
	
	//Get the coupon data if its already been entered
	$discount = get_post_meta($post->ID, 'wp_coupons_discount_percent', true);
	$code = get_post_meta($post->ID, 'wp_coupons_discount_code', true);
	$url = get_post_meta($post->ID, 'wp_coupons_discount_url', true);
	$description = get_post_meta($post->ID, 'wp_coupons_discount_description', true);
	$call_to_action = get_post_meta($post->ID, 'wp_coupons_call_to_action', true);
	$expiration_date = get_post_meta( $post->ID, 'wp_coupons_expiration', true );
	$css_class = get_post_meta( $post->ID, 'wp_coupons_css_class', true );
	$direct_link = get_post_meta($post->ID, 'wp_coupons_direct_link', true);
	$nofollow = get_post_meta($post->ID, 'wp_coupons_nofollow', true);
	$exclude_archive = get_post_meta($post->ID, 'wp_coupons_exclude_archive', true);
	$exclude_rotation = get_post_meta($post->ID, 'wp_coupons_exclude_rotation', true);
	
	//Echo out the fields
	echo '<label for="">' . __('Discount', 'wp_coupons') . '</label>';
	echo '<input type="text" name="wp_coupons_discount_percent" value="' . ($discount ? $discount : '')  . '" class="widefat" maxlength="25" />';

	echo '<label for="">' . __('Discount Code', 'wp_coupons') . '</label>';
	echo '<input type="text" name="wp_coupons_discount_code" value="' . ($code ? $code : '')  . '" class="widefat" maxlength="25" />';

	echo '<label for="">' . __('Discount URL', 'wp_coupons') . '</label>';
	echo '<input type="text" name="wp_coupons_discount_url" value="' . ($url ? $url : '')  . '" class="widefat" maxlength="250" />';     

	echo '<label for="">' . __('Discount Description', 'wp_coupons') . '</label>';
	echo '<textarea name="wp_coupons_discount_description" class="widefat" style="height: 100px;" maxlength="500" />' . ($description ? $description : '') . '</textarea>';

	echo '<label for="">' . __('Call to Action', 'wp_coupons') . '</label>';
	echo '<input type="text" name="wp_coupons_call_to_action" value="' . ($call_to_action ? $call_to_action : '') . '" class="widefat" maxlength="25">';

	echo '<label for="">' . __('Expiration Date', 'wp_coupons') . '</label>';        
    echo '<input type="text" name="wp_coupons_expiration" class="widefat wp-coupons-date" value="' . ($expiration_date ? $expiration_date : '')  . '" maxlength="25" />';

    echo '<label for="">' . __('CSS Class', 'wp_coupons') . '</label>';        
    echo '<input type="text" name="wp_coupons_css_class" class="widefat" value="' . ($css_class ? $css_class : '')  . '" maxlength="250" />';

	echo '<label for="">' . __('Direct Link', 'wp_coupons') . '</label>';
	echo '<input type="checkbox" name="wp_coupons_direct_link" '; if(!empty($direct_link) && $direct_link == "1"){echo "checked";} echo ' value="1" class="widefat" style="margin: 3px 10px 0px 5px;" />';

	echo '<label for="">' . __('NoFollow', 'wp_coupons') . '</label>';
	echo '<input type="checkbox" name="wp_coupons_nofollow" '; if(!empty($nofollow) && $nofollow == "1"){echo "checked";} echo ' value="1" class="widefat" style="margin: 3px 10px 0px 5px;" />';

	echo '<label for="">' . __('Exclude From Archive', 'wp_coupons') . '</label>';
	echo '<input type="checkbox" name="wp_coupons_exclude_archive" '; if(!empty($exclude_archive) && $exclude_archive == "1"){echo "checked";} echo ' value="1" class="widefat" style="margin: 3px 10px 0px 5px;" />';

	echo '<label for="">' . __('Exclude From Rotation', 'wp_coupons') . '</label>';
	echo '<input type="checkbox" name="wp_coupons_exclude_rotation" '; if(!empty($exclude_rotation) && $exclude_rotation == "1"){echo "checked";} echo ' value="1" class="widefat" style="margin: 3px 10px 0px 5px;" />';

	echo '<span style="float: right;">';
	echo '<label for="">' . __('Shortcode', 'wp_coupons') . ': </label>';
	echo '<span style="font-weight: bold;">' . '[coupon id="' . $post->ID . '"]' . '</span>';
	echo '</span>';

	echo '<script type="text/javascript">
	    jQuery(document).ready(function() {
	        jQuery(".wp-coupons-date").datepicker({
	            dateFormat : "mm/dd/yy"
	        });
	    });
	</script>';
}

//Save the Metabox Data
function wp_coupons_save_meta($post_id, $post) {
	
	//verify this came from the our screen and with proper authorization, because save_post can be triggered at other times
	if(empty($_POST['wp_coupons_meta_noncename']) || !wp_verify_nonce($_POST['wp_coupons_meta_noncename'], plugin_basename(__FILE__))) {
		return $post->ID;
	}

	//Is the user allowed to edit the post or page?
	if(!current_user_can('edit_post', $post->ID)) {
		return $post->ID;
	}
		
	// OK, we're authenticated: we need to find and save the data
	$wp_coupons_meta = array();
	$wp_coupons_meta['wp_coupons_discount_percent'] = (isset($_POST['wp_coupons_discount_percent']) ? $_POST['wp_coupons_discount_percent'] : "");
	$wp_coupons_meta['wp_coupons_discount_code'] = (isset($_POST['wp_coupons_discount_code']) ? $_POST['wp_coupons_discount_code'] : "");
	$wp_coupons_meta['wp_coupons_discount_url'] = (isset($_POST['wp_coupons_discount_url']) ? $_POST['wp_coupons_discount_url'] : "");
	$wp_coupons_meta['wp_coupons_discount_description'] = (isset($_POST['wp_coupons_discount_description']) ? $_POST['wp_coupons_discount_description'] : "");
	$wp_coupons_meta['wp_coupons_call_to_action'] = (isset($_POST['wp_coupons_call_to_action']) ? $_POST['wp_coupons_call_to_action'] : "");
	$wp_coupons_meta['wp_coupons_expiration'] = (isset($_POST['wp_coupons_expiration']) ? $_POST['wp_coupons_expiration'] : "");
	$wp_coupons_meta['wp_coupons_css_class'] = (isset($_POST['wp_coupons_css_class']) ? $_POST['wp_coupons_css_class'] : "");
	$wp_coupons_meta['wp_coupons_direct_link'] = (isset($_POST['wp_coupons_direct_link']) ? $_POST['wp_coupons_direct_link'] : "");
	$wp_coupons_meta['wp_coupons_nofollow'] = (isset($_POST['wp_coupons_nofollow']) ? $_POST['wp_coupons_nofollow'] : "");
	$wp_coupons_meta['wp_coupons_exclude_archive'] = (isset($_POST['wp_coupons_exclude_archive']) ? $_POST['wp_coupons_exclude_archive'] : "");
	$wp_coupons_meta['wp_coupons_exclude_rotation'] = (isset($_POST['wp_coupons_exclude_rotation']) ? $_POST['wp_coupons_exclude_rotation'] : "");
	
	//Add values of coupons meta as custom fields
	foreach($wp_coupons_meta as $key => $value) {

		if($post->post_type == 'revision') {
			return; //Don't store custom data twice
		} 
		if(get_post_meta($post->ID, $key, FALSE)) { //If the custom field already has a value
			update_post_meta($post->ID, $key, $value);
		} 
		else { 
			add_post_meta($post->ID, $key, $value); //If the custom field doesn't have a value
		}
		if(!$value) {
			delete_post_meta($post->ID, $key); //Delete if blank
		} 
	}
}
add_action('save_post', 'wp_coupons_save_meta', 1, 2); // save the custom fields

/* Single Post Coupon Meta Box
/* This will be used to force specific posts/pages to show a certain coupon if there is a widget/shortcode present.
/***********************************************************************************************************************/
//Add Coupon Meta Box to Posts/Pages
function wp_coupons_add_meta_boxes() {
	$post_types = get_post_types(array('public' => true)); //get all available post types
	unset($post_types['coupon']); //don't show force coupon meta on coupon post type
    add_meta_box('wp_coupons_coupon', 'WP Coupons', 'wp_coupons_post_load_meta_box', $post_types, 'side', 'default');
}
add_action( 'add_meta_boxes', 'wp_coupons_add_meta_boxes');

//Load HTML for Coupon Details Meta Box
function wp_coupons_post_load_meta_box() {
	global $post;

	//Get the coupon data if its already been entered
	$coupon_post_id = get_post_meta($post->ID, 'wp_coupons_coupon_post_id', true);

	$args = array(
		'posts_per_page'   => -1,
		'post_type'        => 'coupon',
		'post_status'      => 'publish',
		'order_by'         => 'title'
	);
	$coupon_array = get_posts( $args );

	echo "<label for='wp_coupons_coupon_post_id'>" . __('Force Coupon', 'wp_coupons') . "</label>";
	echo "<select id='wp_coupons_coupon_post_id' name='wp_coupons_coupon_post_id' class='widefat'>";
		echo "<option value=''>" . __('Select a Coupon', 'wp_coupons') . "</option>";
		if(!empty($coupon_array)) {
			foreach($coupon_array as $coupon) {
				echo "<option value='" . $coupon->ID . "' "; if($coupon->ID == $coupon_post_id){echo "selected=selected";} echo ">" . $coupon->post_title . "</option>";
			}
		}
	echo "</select>";
	
	//Noncename needed to verify where the data originated
	echo '<input type="hidden" name="wp_coupons_meta_noncename" id="wp_coupons_meta_noncename" value="' . wp_create_nonce(plugin_basename(__FILE__)) . '" />';
}

//Save the Metabox Data
function wp_coupons_post_save_meta($post_id, $post) {
	
	//verify this came from the our screen and with proper authorization, because save_post can be triggered at other times
	if(empty($_POST['wp_coupons_meta_noncename']) || !wp_verify_nonce($_POST['wp_coupons_meta_noncename'], plugin_basename(__FILE__))) {
		return $post->ID;
	}

	//Is the user allowed to edit the post or page?
	if(!current_user_can('edit_post', $post->ID)) {
		return $post->ID;
	}
		
	//OK, we're authenticated: we need to find and save the data
	$wp_coupons_meta = array();
	$wp_coupons_meta['wp_coupons_coupon_post_id'] = (isset($_POST['wp_coupons_coupon_post_id']) ? $_POST['wp_coupons_coupon_post_id'] : "");
	
	//Add values of $events_meta as custom fields
	foreach ($wp_coupons_meta as $key => $value) {

		if($post->post_type == 'revision') {
			return; // Don't store custom data twice
		} 
		if(get_post_meta($post->ID, $key, FALSE)) { // If the custom field already has a value
			update_post_meta($post->ID, $key, $value);
		} 
		else { // If the custom field doesn't have a value
			add_post_meta($post->ID, $key, $value);
		}
		if(!$value) {
			delete_post_meta($post->ID, $key); // Delete if blank
		} 
	}
}
add_action('save_post', 'wp_coupons_post_save_meta', 1, 2); // save the custom fields