<?php

//default display options
function wp_coupons_default_display_options() {
	$defaults = array(
		'wp_coupons_enable_archive' => "1",
		'wp_coupons_enable_single' => "1",
		'wp_coupons_single_template' => 'post',
		'wp_coupons_single_position' => 'right',
		'wp_coupons_single_template_image' => '',
		'wp_coupons_hide_single_template_title' => '',
		'wp_coupons_hide_breadcrumbs' => '',
		'wp_coupons_archive_slug' => 'coupons',
		'wp_coupons_nav_title' => __('All Coupons', 'wp_coupons'),
		'wp-coupons_nav_style' => '',
		'wp_coupons_enable_subnav' => '',
		'wp_coupons_archive_layout' => '',
		'wp_coupons_archive_sort_order' => '',
		'wp_coupons_archive_facebook_image' => '',
		'wp_coupons_archive_twitter_image' => '',
		'wp_coupons_call_to_action' => __('Get This Deal', 'wp_coupons'),
		'wp_coupons_display_discount_codes' => '',
		'wp_coupons_hide_coupon_type_tags' => '',
		'wp_coupons_no_code_needed_text' => __('No Code Needed', 'wp_coupons'),
		'wp_coupons_hide_no_code_needed' => '',
		'wp_coupons_click_to_reveal' => '',
		'wp_coupons_click_to_reveal_text' => __('Click to Reveal', 'wp_coupons'),
		'wp_coupons_click_to_reveal_behavior' => 'newtabpopup',
		'wp_coupons_description_height' => '90px',
		'wp_coupons_display_expiration' => '',
		'wp_coupons_display_related_coupons' => '',
		'wp_coupons_related_coupons_locations' => array(0 => "coupon"),
		'wp_coupons_related_coupons_text' => __('Related Coupons', 'wp_coupons'),
		'wp_coupons_related_coupons_hook' => '',
		'wp_coupons_related_coupons_hook_priority' => '',
		'wp_coupons_wrapper_width' => '1200px',
		'wp_coupons_wrapper_padding' => '20px',
		'wp_coupons_archive_limit' => 9,
		'wp_coupons_force_global_widget' => '',
		'wp_coupons_force_home' => '',
		'wp_coupons_attribution' => '',
		'wp_coupons_affiliate_id' => ''
	);
	return apply_filters('wp_coupons_default_display_options', $defaults);
}

//display options callback
function wp_coupons_display_options_callback() {
	echo '<p>' . __('Change the primary display settings for your coupons.', 'wp_coupons') . '</p>';
}

//initialize styling options
function wp_coupons_initialize_display_options() {

	//get/create option
	if(false == get_option('wp_coupons_display_options')) {	
		add_option('wp_coupons_display_options', apply_filters('wp_coupons_default_display_options', wp_coupons_default_display_options()));
	}

	//display settings main section
	add_settings_section('wp_coupons_display_settings', __('Display Options', 'wp_coupons'), 'wp_coupons_display_options_callback', 'wp_coupons_display_options');

	//Enable Coupon Archive Template
	add_settings_field(
		'wp_coupons_enable_archive',
		wp_coupons_title(__('Enable Coupon Archive Template', 'wp_coupons'), 'wp_coupons_enable_archive') . wp_coupons_tooltip('https://wpcoupons.io/docs/display-options/#enable-coupon-archive-template'),
		'wp_coupons_print_input',
		'wp_coupons_display_options',
		'wp_coupons_display_settings',
		array(
			'id' => 'wp_coupons_enable_archive',
			'tooltip' => __('If checked, this will auto generate a coupon archive using the archive slug below. Disable this if you would rather use the [wp_coupons] shortcode to print the coupon archive inside of a page. This can be useful if your theme has some conflicts with our archive template.', 'wp_coupons')
		)
	);

	//Enable Single Coupon Template
	add_settings_field(
		'wp_coupons_enable_single',
		wp_coupons_title(__('Enable Single Coupon Template', 'wp_coupons'), 'wp_coupons_enable_single') . wp_coupons_tooltip('https://wpcoupons.io/docs/display-options/#enable-single-coupon-template'),
		'wp_coupons_print_input',
		'wp_coupons_display_options',
		'wp_coupons_display_settings',
		array(
			'id' => 'wp_coupons_enable_single',
			'tooltip' => __("If checked, single coupon posts will display using our custom template. Disable this if you would rather use your theme's default post template to display single coupon posts. This can be useful if your theme has some conflicts with our custom single post template.", 'wp_coupons')
		)
	);

	//Single Coupon Template
	add_settings_field(
		'wp_coupons_single_template',
		wp_coupons_title(__('Single Coupon Template', 'wp_coupons'), 'wp_coupons_single_template') . wp_coupons_tooltip('https://wpcoupons.io/docs/display-options/#single-coupon-template'),
		'wp_coupons_print_input',
		'wp_coupons_display_options',
		'wp_coupons_display_settings',
		array(
			'input'    => 'select',
			'id'       => 'wp_coupons_single_template',
			'options'  => array(
				'post' => __('Post Template', 'wp_coupons'),
				'page' => __('Page Template', 'wp_coupons'),
				),
			'tooltip'  => __('If the previous option is unchecked, this will allow you to choose which default template is used for single coupon posts. Default: Post Template', 'wp_coupons')
		)
	);

	//Single Coupon Panel Position
	add_settings_field(
		'wp_coupons_single_position',
		wp_coupons_title(__('Single Coupon Panel Position', 'wp_coupons'), 'wp_coupons_single_position') . wp_coupons_tooltip('https://wpcoupons.io/docs/display-options/#single-coupon-panel-position'),
		'wp_coupons_print_input',
		'wp_coupons_display_options',
		'wp_coupons_display_settings',
		array(
			'input'    => 'select',
			'id'       => 'wp_coupons_single_position',
			'options'  => array(
				'right' => __('Right', 'wp_coupons'),
				'left' => __('Left', 'wp_coupons'),
				'top' => __('Top', 'wp_coupons')
				),
			'tooltip'  => __('This will change the position of the coupon panel on the single post template. Default: Right', 'wp_coupons')
		)
	);

	//Display Single Template Image
	add_settings_field(
		'wp_coupons_single_template_image',
		wp_coupons_title(__('Display Single Template Image', 'wp_coupons'), 'wp_coupons_single_template_image') . wp_coupons_tooltip('https://wpcoupons.io/docs/display-options/#display-single-template-image'),
		'wp_coupons_print_input',
		'wp_coupons_display_options',
		'wp_coupons_display_settings',
		array(
			'id' => 'wp_coupons_single_template_image',
			'tooltip' => __("If checked, the featured image will be displayed on the coupon panel in your Single Coupon Posts. This option is only relevant when our Enable Single Coupon Template option is turned off. It is helpful for those who have themes that do not display featured images on their page and post templates. Default: Unchecked", 'wp_coupons')
		)
	);

	//Hide Single Coupon Post Title
	add_settings_field(
		'wp_coupons_hide_single_template_title',
		wp_coupons_title(__('Hide Single Template Title', 'wp_coupons'), 'wp_coupons_hide_single_template_title') . wp_coupons_tooltip('https://wpcoupons.io/docs/display-options/#hide-single-template-title'),
		'wp_coupons_print_input',
		'wp_coupons_display_options',
		'wp_coupons_display_settings',
		array(
			'id' => 'wp_coupons_hide_single_template_title',
			'tooltip' => __("If checked, this will prevent the post title from printing above the content area on your Single Coupon Posts. This option is only relevant when our Enable Single Coupon Template option is turned on. Default: Unchecked", 'wp_coupons')
		)
	);

	//Hide Breadcrumbs
	add_settings_field(
		'wp_coupons_hide_breadcrumbs',
		wp_coupons_title(__('Hide Breadcrumbs', 'wp_coupons'), 'wp_coupons_hide_breadcrumbs') . wp_coupons_tooltip('https://wpcoupons.io/docs/display-options/#hide-breadcrumbs'),
		'wp_coupons_print_input',
		'wp_coupons_display_options',
		'wp_coupons_display_settings',
		array(
			'id' => 'wp_coupons_hide_breadcrumbs',
			'tooltip' => __("This will disable the breadcrumbs archive link that displays above the content on the Single Coupon Posts. Default: Unchecked", 'wp_coupons')
		)
	);

	//Archive URL
	add_settings_field(
		'wp_coupons_archive_slug',
		wp_coupons_title(__('Archive URL', 'wp_coupons'), 'wp_coupons_archive_slug') . wp_coupons_tooltip('https://wpcoupons.io/docs/display-options/#archive-url'),
		'wp_coupons_print_input',
		'wp_coupons_display_options',
		'wp_coupons_display_settings',
		array(
			'input' => 'text',
			'id' => 'wp_coupons_archive_slug',
			'tooltip' => __('This will change the slug for the coupon archive URL as well as the single coupon URLs. Default: http://example.com/coupons/', 'wp_coupons')
		)
	);

	//Nav Title
	add_settings_field(
		'wp_coupons_nav_title',
		wp_coupons_title(__('Nav Title', 'wp_coupons'), 'wp_coupons_nav_title') . wp_coupons_tooltip('https://wpcoupons.io/docs/display-options/#nav-title'),
		'wp_coupons_print_input',
		'wp_coupons_display_options',
		'wp_coupons_display_settings',
		array(
			'input' => 'text',
			'id' => 'wp_coupons_nav_title',
			'tooltip' => __('This will change the text for the first navigation element on the coupon archive template and shortcode. Default: All Coupons', 'wp_coupons')
		)
	);

	//Nav Style
	add_settings_field(
		'wp_coupons_nav_style',
		wp_coupons_title(__('Nav Style', 'wp_coupons'), 'wp_coupons_nav_style') . wp_coupons_tooltip('https://wpcoupons.io/docs/display-options/#nav-style'),
		'wp_coupons_print_input',
		'wp_coupons_display_options',
		'wp_coupons_display_settings',
		array(
			'input'    => 'select',
			'id'       => 'wp_coupons_nav_style', 
			'options'  => array(
				'' => __('Default', 'wp_coupons'),
				'vertical' => __('Vertical', 'wp_coupons'),
				'dropdown' => __('Dropdown', 'wp_coupons')
			),
			'tooltip'  => __('This will change the style and placement of your coupon archive navigation.', 'wp_coupons')
		)
	);

	//Enable Tag Subnav
	add_settings_field(
		'wp_coupons_enable_subnav',
		wp_coupons_title(__('Enable Tag Subnav', 'wp_coupons'), 'wp_coupons_enable_subnav') . wp_coupons_tooltip('https://wpcoupons.io/docs/display-options/#enable-tag-subnav'),
		'wp_coupons_print_input',
		'wp_coupons_display_options',
		'wp_coupons_display_settings',
		array(
			'id' => 'wp_coupons_enable_subnav',
			'tooltip' => __('If checked, this will enable tags to be used as subnavigation for the Coupon Archive and Archive Shortcode. You may need to refresh your permalink settings after enabling this option. Default: Unchecked', 'wp_coupons')
		)
	);

	//Archive Layout
	add_settings_field(
		'wp_coupons_archive_layout',
		wp_coupons_title(__('Archive Layout', 'wp_coupons'), 'wp_coupons_archive_layout') . wp_coupons_tooltip('https://wpcoupons.io/docs/display-options/#archive-layout'),
		'wp_coupons_print_input',
		'wp_coupons_display_options',
		'wp_coupons_display_settings',
		array(
			'input' => 'select',
			'id' => 'wp_coupons_archive_layout',
			'options'  => array(
				'2' => __('2 Columns', 'wp_coupons'),
				'' => __('3 Columns (Default)', 'wp_coupons'),
				'4' => __('4 Columns', 'wp_coupons'),
				'5' => __('5 Columns', 'wp_coupons'),
				'list' => __('List View', 'wp_coupons'),
				'list-compact' => __('List Compact View', 'wp_coupons'),
				'list-minimal' => __('List Minimal View', 'wp_coupons')
			),
			'tooltip' => __('This will change the layout of the main coupon archive as well as the [wp_coupons] shortcode.', 'wp_coupons')
		)
	);

	//Archive Sort Order
	add_settings_field(
		'wp_coupons_archive_sort_order',
		wp_coupons_title(__('Archive Sort Order', 'wp_coupons'), 'wp_coupons_archive_sort_order') . wp_coupons_tooltip('https://wpcoupons.io/docs/display-options/#archive-sort-order'),
		'wp_coupons_print_input',
		'wp_coupons_display_options',
		'wp_coupons_display_settings',
		array(
			'input' => 'select',
			'id' => 'wp_coupons_archive_sort_order',
			'options'  => array(
				'' => __('Date (Default)', 'wp_coupons'),
				'modified' => __('Last Modified', 'wp_coupons'),
				'title' => __('Title', 'wp_coupons'),
				'rand' => __('Random', 'wp_coupons')
			),
			'tooltip' => __('This will change the sort order of the main coupon archive as well as the [wp_coupons] shortcode.', 'wp_coupons')
		)
	);

	//Facebook Image
	add_settings_field(
		'wp_coupons_archive_facebook_image',
		wp_coupons_title(__('Archive Facebook Image', 'wp_coupons'), 'wp_coupons_archive_facebook_image') . wp_coupons_tooltip('https://wpcoupons.io/docs/open-graph/'),
		'wp_coupons_print_input',
		'wp_coupons_display_options',
		'wp_coupons_display_settings',
		array(
			'input' => 'image',
			'id' => 'wp_coupons_archive_facebook_image',
			'tooltip' => __('Add an image URL here to print out an Open Graph image tag used for Facebook on your coupon archive. This is only relevant when using our Coupon Archive Template.', 'wp_coupons')
		)
	);

	//Twitter Image
	add_settings_field(
		'wp_coupons_archive_twitter_image',
		wp_coupons_title(__('Archive Twitter Image', 'wp_coupons'), 'wp_coupons_archive_twitter_image') . wp_coupons_tooltip('https://wpcoupons.io/docs/open-graph/'),
		'wp_coupons_print_input',
		'wp_coupons_display_options',
		'wp_coupons_display_settings',
		array(
			'input' => 'image',
			'id' => 'wp_coupons_archive_twitter_image',
			'tooltip' => __('Add an image URL here to print out an Open Graph image tag used for Twitter. This is only relevant when using our Coupon Archive Template.', 'wp_coupons')
		)
	);
	
	//Call to Action
	add_settings_field(
		'wp_coupons_call_to_action',
		wp_coupons_title(__('Call to Action', 'wp_coupons'), 'wp_coupons_call_to_action') . wp_coupons_tooltip('https://wpcoupons.io/docs/display-options/#call-to-action'),
		'wp_coupons_print_input',
		'wp_coupons_display_options',
		'wp_coupons_display_settings',
		array(
			'input' => 'text',
			'id' => 'wp_coupons_call_to_action',
			'tooltip' => __('This will change the call to action text on all coupon panels and buttons. Default: Get This Deal | Max Length: 25 Characters', 'wp_coupons')
		)
	);

	//Display Discount Codes
	add_settings_field(
		'wp_coupons_display_discount_codes',
		wp_coupons_title(__('Display Discount Codes', 'wp_coupons'), 'wp_coupons_display_discount_codes') . wp_coupons_tooltip('https://wpcoupons.io/docs/display-options/#display-discount-codes'),
		'wp_coupons_print_input',
		'wp_coupons_display_options',
		'wp_coupons_display_settings',
		array(
			'id' => 'wp_coupons_display_discount_codes',
			'tooltip' => __('If checked, discount codes will be displayed on coupon panels across all views. Default: Unchecked', 'wp_coupons')
		)
	);

	//Hide Coupon Type Tags
	add_settings_field(
		'wp_coupons_hide_coupon_type_tags',
		wp_coupons_title(__('Hide Coupon Type Tags', 'wp_coupons'), 'wp_coupons_hide_coupon_type_tags') . wp_coupons_tooltip('https://wpcoupons.io/docs/display-options/#hide-coupon-type-tags'),
		'wp_coupons_print_input',
		'wp_coupons_display_options',
		'wp_coupons_display_settings',
		array(
			'id' => 'wp_coupons_hide_coupon_type_tags',
			'tooltip' => __('If checked, the Coupon Type tags will no longer be displayed on coupon panels in any view. Default: Unchecked', 'wp_coupons')
		)
	);

	//No Code Needed Text
	add_settings_field(
		'wp_coupons_no_code_needed_text',
		wp_coupons_title(__('No Code Needed Text', 'wp_coupons'), 'wp_coupons_no_code_needed_text') . wp_coupons_tooltip('https://wpcoupons.io/docs/display-options/#no-code-needed-text'),
		'wp_coupons_print_input',
		'wp_coupons_display_options',
		'wp_coupons_display_settings',
		array(
			'input' => 'text',
			'id' => 'wp_coupons_no_code_needed_text',
			'tooltip' => __('This will change the text displayed on single coupon posts when no discount code is present. Default: No Code Needed', 'wp_coupons')
		)
	);

	//Display Discount Codes
	add_settings_field(
		'wp_coupons_hide_no_code_needed',
		wp_coupons_title(__('Hide No Code Needed', 'wp_coupons'), 'wp_coupons_hide_no_code_needed') . wp_coupons_tooltip('https://wpcoupons.io/docs/display-options/#hide-no-code-needed'),
		'wp_coupons_print_input',
		'wp_coupons_display_options',
		'wp_coupons_display_settings',
		array(
			'id' => 'wp_coupons_hide_no_code_needed',
			'tooltip' => __('If checked, the No Code Needed box will not be displayed on single coupon posts if there is no discount code present. Default: Unchecked', 'wp_coupons')
		)
	);

	//Click to Reveal
	add_settings_field(
		'wp_coupons_click_to_reveal',
		wp_coupons_title(__('Click to Reveal', 'wp_coupons'), 'wp_coupons_click_to_reveal') . wp_coupons_tooltip('https://wpcoupons.io/docs/click-to-reveal-coupons'),
		'wp_coupons_print_input',
		'wp_coupons_display_options',
		'wp_coupons_display_settings',
		array(
			'id' => 'wp_coupons_click_to_reveal',
			'tooltip' => __('If checked, discount codes will be hidden by default and require the user to click to reveal a popup with the discount code, coupon info, and a link to the deal. The Display Discount Codes option must also be enabled for this to work. Default: Unchecked', 'wp_coupons')
		)
	);

	//Click to Reveal Text
	add_settings_field(
		'wp_coupons_click_to_reveal_text',
		wp_coupons_title(__('Click to Reveal Text', 'wp_coupons'), 'wp_coupons_click_to_reveal_text') . wp_coupons_tooltip('https://wpcoupons.io/docs/click-to-reveal-coupons'),
		'wp_coupons_print_input',
		'wp_coupons_display_options',
		'wp_coupons_display_settings',
		array(
			'input' => 'text',
			'id' => 'wp_coupons_click_to_reveal_text',
			'tooltip' => __('This will change the Click to Reveal text that is displayed on coupon panels when Click to Reveal is enabled. Default: Click to Reveal', 'wp_coupons')
		)
	);

	//Click to Reveal Behavior
	add_settings_field(
		'wp_coupons_click_to_reveal_behavior',
		wp_coupons_title(__('Click to Reveal Behavior', 'wp_coupons'), 'wp_coupons_click_to_reveal_behavior') . wp_coupons_tooltip('https://wpcoupons.io/docs/click-to-reveal-coupons'),
		'wp_coupons_print_input',
		'wp_coupons_display_options',
		'wp_coupons_display_settings',
		array(
			'input'    => 'select',
			'id'       => 'wp_coupons_click_to_reveal_behavior', 
			'options'  => array(
				'newtabpopup' => __('New Tab + Popup', 'wp_coupons'),
				'popup' => __('Popup Only', 'wp_coupons')
			),
			'tooltip'  => __('If the Click to Reveal option is enabled, this will control the behavior of the popup and new tab.', 'wp_coupons')
		)
	);

	//Coupon Description Height
	add_settings_field(
		'wp_coupons_description_height',
		wp_coupons_title(__('Coupon Description Height (px)', 'wp_coupons'), 'wp_coupons_description_height') . wp_coupons_tooltip('https://wpcoupons.io/docs/display-options/#description-height'),
		'wp_coupons_print_input',
		'wp_coupons_display_options',
		'wp_coupons_display_settings',
		array(
			'input' => 'text',
			'id' => 'wp_coupons_description_height',
			'tooltip' => __('This will change the height of the coupon description container on your coupon panels. Default: 90px', 'wp_coupons')
		)
	);

	//Display Expiration Dates
	add_settings_field(
		'wp_coupons_display_expiration',
		wp_coupons_title(__('Display Expiration Dates', 'wp_coupons'), 'wp_coupons_display_expiration') . wp_coupons_tooltip('https://wpcoupons.io/docs/display-options/#display-expiration-dates'),
		'wp_coupons_print_input',
		'wp_coupons_display_options',
		'wp_coupons_display_settings',
		array(
			'id' => 'wp_coupons_display_expiration',
			'tooltip' => __('If checked, expiration dates will be displayed on coupon panels across all views if they are set. Default: Unchecked', 'wp_coupons')
		)
	);

	//Display Related Coupons
	add_settings_field(
		'wp_coupons_display_related_coupons',
		wp_coupons_title(__('Display Related Coupons', 'wp_coupons'), 'wp_coupons_display_related_coupons') . wp_coupons_tooltip('https://wpcoupons.io/docs/display-options/#display-related-coupons'),
		'wp_coupons_print_input',
		'wp_coupons_display_options',
		'wp_coupons_display_settings',
		array(
			'id' => 'wp_coupons_display_related_coupons',
			'tooltip' => __('If checked, a row of related coupons will be displayed below your post content. See below to manage which locations you would like related coupons to show up. Default: Unchecked', 'wp_coupons')
		)
	);

	//Related Coupons Locations
	add_settings_field(
		'wp_coupons_related_coupons_locations',
		wp_coupons_title(__('Related Coupons Locations', 'wp_coupons'), 'wp_coupons_related_coupons_locations') . wp_coupons_tooltip('https://wpcoupons.io/docs/display-options/#related-coupons-locations'),
		'wp_coupons_print_related_coupons_locations',
		'wp_coupons_display_options',
		'wp_coupons_display_settings',
		array(
			'id' => 'wp_coupons_related_coupons_locations',
			'tooltip' => __('Please select the post types you would like your related coupons to show up on. Default: Coupons', 'wp_coupons')
		)
	);

	//Related Coupons Text
	add_settings_field(
		'wp_coupons_related_coupons_text',
		wp_coupons_title(__('Related Coupons Text', 'wp_coupons'), 'wp_coupons_related_coupons_text') . wp_coupons_tooltip('https://wpcoupons.io/docs/display-options/#related-coupons-text'),
		'wp_coupons_print_input',
		'wp_coupons_display_options',
		'wp_coupons_display_settings',
		array(
			'input' => 'text',
			'id' => 'wp_coupons_related_coupons_text',
			'tooltip' => __('This will change the text that is displayed above your related coupons. Default: Related Coupons', 'wp_coupons')
		)
	);

	//Related Coupons Hook
	add_settings_field(
		'wp_coupons_related_coupons_hook',
		wp_coupons_title(__('Related Coupons Hook', 'wp_coupons'), 'wp_coupons_related_coupons_hook') . wp_coupons_tooltip('https://wpcoupons.io/docs/display-options/#related-coupons-hook'),
		'wp_coupons_print_input',
		'wp_coupons_display_options',
		'wp_coupons_display_settings',
		array(
			'input' => 'text',
			'id' => 'wp_coupons_related_coupons_hook',
			'tooltip' => __('This will cause the related coupons section to print out on the specified hook instead of directly after the_content.', 'wp_coupons')
		)
	);

	//Related Coupons Hook Priority
	add_settings_field(
		'wp_coupons_related_coupons_hook_priority',
		wp_coupons_title(__('Related Coupons Hook Priority', 'wp_coupons'), 'wp_coupons_related_coupons_hook_priority') . wp_coupons_tooltip('https://wpcoupons.io/docs/display-options/#related-coupons-hook-priority'),
		'wp_coupons_print_input',
		'wp_coupons_display_options',
		'wp_coupons_display_settings',
		array(
			'input' => 'text',
			'id' => 'wp_coupons_related_coupons_hook_priority',
			'tooltip' => __('When using the previous option to print related coupons on a custom hook, this will set the priority that the function prints in relation to others using the same hook.', 'wp_coupons')
		)
	);

	//Template Wrapper Width
	add_settings_field(
		'wp_coupons_wrapper_width',
		wp_coupons_title(__('Page Width (px)', 'wp_coupons'), 'wp_coupons_wrapper_width') . wp_coupons_tooltip('https://wpcoupons.io/docs/display-options/#page-width'),
		'wp_coupons_print_input',
		'wp_coupons_display_options',
		'wp_coupons_display_settings',
		array(
			'input' => 'text',
			'id' => 'wp_coupons_wrapper_width',
			'tooltip' => __('This will change the width of the content area for the coupon archive and single coupon posts. Default: 1200px', 'wp_coupons')
		)
	);

	//Template Wrapper Padding
	add_settings_field(
		'wp_coupons_wrapper_padding',
		wp_coupons_title(__('Page Padding (px)', 'wp_coupons'), 'wp_coupons_wrapper_padding') . wp_coupons_tooltip('https://wpcoupons.io/docs/display-options/#page-padding'),
		'wp_coupons_print_input',
		'wp_coupons_display_options',
		'wp_coupons_display_settings',
		array(
			'input' => 'text',
			'id' => 'wp_coupons_wrapper_padding',
			'tooltip' => __('This will change the responsive padding of the content area. Default: 20px', 'wp_coupons')
		)
	);

	//Archive Post Limit
	add_settings_field(
		'wp_coupons_archive_limit',
		wp_coupons_title(__('Archive Post Limit', 'wp_coupons'), 'wp_coupons_archive_limit') . wp_coupons_tooltip('https://wpcoupons.io/docs/display-options/#archive-post-limit'),
		'wp_coupons_print_input',
		'wp_coupons_display_options',
		'wp_coupons_display_settings',
		array(
			'input' => 'text',
			'id' => 'wp_coupons_archive_limit',
			'tooltip' => __('This will change the number of posts per page displayed in the main Coupon Archive. Default: 9', 'wp_coupons')
		)
	);

	//Force Global Widget Coupon
	add_settings_field(
		'wp_coupons_force_global_widget',
		wp_coupons_title(__('Force Global Widget Coupon', 'wp_coupons'), 'wp_coupons_force_global_widget') . wp_coupons_tooltip('https://wpcoupons.io/docs/display-options/#force-global-widget-coupon'),
		'wp_coupons_print_input',
		'wp_coupons_display_options',
		'wp_coupons_display_settings',
		array(
			'input'    => 'select',
			'id'       => 'wp_coupons_force_global_widget', 
			'options'  => wp_coupons_coupon_array(),
			'tooltip'  => __('This will force the coupon widget to display a specific coupon globally.', 'wp_coupons')
		)
	);

	//Force Home Page Coupon
	add_settings_field(
		'wp_coupons_force_home',
		wp_coupons_title(__('Force Home Page Coupon', 'wp_coupons'), 'wp_coupons_force_home') . wp_coupons_tooltip('https://wpcoupons.io/docs/display-options/#force-home-page-coupon'),
		'wp_coupons_print_input',
		'wp_coupons_display_options',
		'wp_coupons_display_settings',
		array(
			'input'    => 'select',
			'id'       => 'wp_coupons_force_home', 
			'options'  => wp_coupons_coupon_array(),
			'tooltip'  => __('This will force the coupon widget to display a specific coupon if on the home page (overrides global widget coupon).', 'wp_coupons')
		)
	);

	//Attribution Link
	add_settings_field(
		'wp_coupons_attribution',
		wp_coupons_title(__('Attribution Link', 'wp_coupons'), 'wp_coupons_attribution') . wp_coupons_tooltip('https://wpcoupons.io/docs/display-options/#attribution-link'),
		'wp_coupons_print_input',
		'wp_coupons_display_options',
		'wp_coupons_display_settings',
		array(
			'id'       => 'wp_coupons_attribution', 
			'tooltip'  => __('If checked, this will display a "Powered by WP Coupons" link underneath the coupon widget. If you are in our affiliate program, make sure to enter your ID below.', 'wp_coupons')
		)
	);

	//Affiliate ID
	add_settings_field(
		'wp_coupons_affiliate_id',
		wp_coupons_title(__('Affiliate ID', 'wp_coupons'), 'wp_coupons_affiliate_id') . wp_coupons_tooltip('https://wpcoupons.io/docs/display-options/#affiliate-id'),
		'wp_coupons_print_input',
		'wp_coupons_display_options',
		'wp_coupons_display_settings',
		array(
			'input' => 'text',
			'id'       => 'wp_coupons_affiliate_id', 
			'tooltip'  => __('Enter your affiliate ID here if you have attribution links enabled to add it to the referral URL.', 'wp_coupons')
		)
	);

	register_setting('wp_coupons_display_options', 'wp_coupons_display_options');
}

//print form inputs
function wp_coupons_print_related_coupons_locations($args) {
	$option = 'wp_coupons_display_options';
    $options = get_option('wp_coupons_display_options');
    $extras = get_option('wp_coupons_extra_options');

    echo "<div style='display: table; width: 100%;'>";
    	echo "<div class='wp-coupons-input-wrapper'>";

    		$post_types = get_post_types(array('public' => true), 'objects', 'and');
			if(!empty($post_types)) {
				if(isset($post_types['attachment'])) {
					unset($post_types['attachment']);
				}
				//echo "<input type='hidden' name='enabled[" . $type . "][" . $handle . "][post_types]' value='' />";
				foreach($post_types as $key => $value) {
					echo "<label for='related-coupons-" . $key . "' style='margin-right: 10px;'>";
						echo "<input type='checkbox' name='" . $option . "[" . $args['id'] . "][]' id='related-coupons-" . $key . "' value='" . $key ."' ";
							if(isset($options['wp_coupons_related_coupons_locations'])) {
								if(in_array($key, $options['wp_coupons_related_coupons_locations'])) {
									echo "checked";
								}
							}
						echo " />" . $value->label;
					echo "</label>";
				}
			}

	    echo "</div>";
	    if(!empty($args['tooltip'])) {
	    	if((empty($extras['wp_coupons_accessibility_mode']) || $extras['wp_coupons_accessibility_mode'] != "1") && $args['id'] != 'wp_coupons_accessibility_mode') {
	    		echo "<div class='wp-coupons-tooltip-text-wrapper'>";
		    		echo "<div class='wp-coupons-tooltip-text-container'>";
		    			echo "<div style='display: table; height: 100%; width: 100%;'>";
		    				echo "<div style='display: table-cell; vertical-align: middle;'>";
		    					echo "<span class='wp-coupons-tooltip-text'>" . $args['tooltip'] . "</span>";
		    				echo "</div>";
		    			echo "</div>";
		    		echo "</div>";
		    	echo "</div>";
	    	}
	    	else {
	    		echo "<p style='font-size: 12px; font-style: italic;'>" . $args['tooltip'] . "</p>";
	    	}
	    	
	    }
	echo "</div>";
}