<?php

//default extra options
function wp_coupons_default_extra_options() {
	$defaults = array(
		'wp_coupons_direct_links' => '0',
		'wp_coupons_direct_links_target' => '_blank',
		'wp_coupons_clipboard_js' => '0',
		'wp_coupons_prepend_permalink' => '0',
		'wp_coupons_exclude_from_search' => '0',
		'wp_coupons_rest_api' => '0',
		'wp_coupons_container_class' => '',
		'wp_coupons_custom_css' => '',
		'wp_coupons_before_archive_content' => '',
		'wp_coupons_after_archive_content' => '',
		'wp_coupons_management_roles' => array(0 => "administrator"),
		'wp_coupons_clean_uninstall' => '0',
		'wp_coupons_accessibility_mode' => '0'
	);
	return apply_filters('wp_coupons_default_extra_options', $defaults);
}

//extra options callback
function wp_coupons_extra_options_callback() {
	echo '<p>' . __('Extra options to change the way certain areas of the plugin work.', 'wp_coupons') . '</p>';
}

//initialize extra options
function wp_coupons_initialize_extra_options() {

	//get/create option
	if(false == get_option( 'wp_coupons_extra_options')) {	
		add_option('wp_coupons_extra_options', apply_filters('wp_coupons_default_extra_options', wp_coupons_default_extra_options()));
	}

	//extra settings section
	add_settings_section('wp_coupons_extra_settings', __('Extra Options', 'wp_coupons'), 'wp_coupons_extra_options_callback', 'wp_coupons_extra_options');
	
	//force direct links
	add_settings_field(
		'wp_coupons_direct_links',
		wp_coupons_title(__('Force Direct Links', 'wp_coupons'), 'wp_coupons_direct_links') . wp_coupons_tooltip('https://wpcoupons.io/docs/extras/#force-direct-links'),
		'wp_coupons_print_input',
		'wp_coupons_extra_options',
		'wp_coupons_extra_settings',
		array(
			'option' => 'wp_coupons_extra_options',
			'id' => 'wp_coupons_direct_links',
			'tooltip' => __('When checked, this will globally force your coupon button links to go directly to the corresponding discount URL if one is set instead of going to the single coupon post, overriding the individual coupon post direct link setting.', 'wp_coupons')
		)
	);
	
	//direct links target
	add_settings_field(
		'wp_coupons_direct_links_target',
		wp_coupons_title(__('Direct Links Target', 'wp_coupons'), 'wp_coupons_direct_links_target') . wp_coupons_tooltip('https://wpcoupons.io/docs/extras/#direct-links-target'),
		'wp_coupons_print_input',
		'wp_coupons_extra_options',
		'wp_coupons_extra_settings',
		array(
			'option' => 'wp_coupons_extra_options',
			'input' => 'select',
			'id' => 'wp_coupons_direct_links_target',
			'options'  => array(
				'_blank' => __('New Tab (_blank)', 'wp_coupons'),
				'_self' => __('Current Tab (_self)', 'wp_coupons')
			),
			'tooltip' => __('This option controls where coupon URLs are opened when direct links are enabled. Default: New Tab (_blank)', 'wp_coupons')
		)
	);
	
	//enable clipboard.js
	add_settings_field(
		'wp_coupons_clipboard_js',
		wp_coupons_title(__('Enable Clipboard.js', 'wp_coupons'), 'wp_coupons_clipboard_js') . wp_coupons_tooltip('https://wpcoupons.io/docs/extras/#enable-clipboardjs'),
		'wp_coupons_print_input',
		'wp_coupons_extra_options',
		'wp_coupons_extra_settings',
		array(
			'option' => 'wp_coupons_extra_options',
			'id' => 'wp_coupons_clipboard_js',
			'tooltip' => __('When checked, this will enable Clipboard.js and display a "Copy" button on your Coupon Codes.', 'wp_coupons')
		)
	);

	//prepend permalink structure
	add_settings_field(
		'wp_coupons_prepend_permalink',
		wp_coupons_title(__('Prepend Permalink Structure', 'wp_coupons'), 'wp_coupons_prepend_permalink') . wp_coupons_tooltip('https://wpcoupons.io/docs/extras/#prepend-permalink-structure'),
		'wp_coupons_print_input',
		'wp_coupons_extra_options',
		'wp_coupons_extra_settings',
		array(
			'option' => 'wp_coupons_extra_options',
			'id' => 'wp_coupons_prepend_permalink',
			'tooltip' => __('When checked, this will prepend your coupon permalinks with your front base (\'with_front\' => true). Default: Unchecked', 'wp_coupons')
		)
	);

	//prepend permalink structure
	add_settings_field(
		'wp_coupons_exclude_from_search',
		wp_coupons_title(__('Exclude from Search', 'wp_coupons'), 'wp_coupons_exclude_from_search') . wp_coupons_tooltip('https://wpcoupons.io/docs/extras/#exclude-from-search'),
		'wp_coupons_print_input',
		'wp_coupons_extra_options',
		'wp_coupons_extra_settings',
		array(
			'option' => 'wp_coupons_extra_options',
			'id' => 'wp_coupons_exclude_from_search',
			'tooltip' => __('When checked, this will prevent your coupons from showing up in front end search results. Default: Unchecked', 'wp_coupons')
		)
	);

	//Show in REST API
	add_settings_field(
		'wp_coupons_rest_api',
		wp_coupons_title(__('Show in REST API', 'wp_coupons'), 'wp_coupons_rest_api') . wp_coupons_tooltip('https://wpcoupons.io/docs/extras/#show-in-rest-api'),
		'wp_coupons_print_input',
		'wp_coupons_extra_options',
		'wp_coupons_extra_settings',
		array(
			'option' => 'wp_coupons_extra_options',
			'id' => 'wp_coupons_rest_api',
			'tooltip' => __('When checked, this will allow your coupon posts to show up when using the REST API. Default: Unchecked', 'wp_coupons')
		)
	);
	
	//custom template container class
	add_settings_field(
		'wp_coupons_container_class',
		wp_coupons_title(__('Custom Template Container Class', 'wp_coupons'), 'wp_coupons_container_class') . wp_coupons_tooltip('https://wpcoupons.io/docs/extras/#custom-template-container-class'),
		'wp_coupons_print_input',
		'wp_coupons_extra_options',
		'wp_coupons_extra_settings',
		array(
			'option' => 'wp_coupons_extra_options',
			'input' => 'text',
			'id' => 'wp_coupons_container_class',
			'tooltip' => __('Here you can add a CSS class that will be added to the custom single coupon template container div. If adding multiple classes, add a space between each one.', 'wp_coupons')
		)
	);
	
	//custom css
	add_settings_field(
		'wp_coupons_custom_css',
		wp_coupons_title(__('Custom CSS', 'wp_coupons'), 'wp_coupons_custom_css') . wp_coupons_tooltip('https://wpcoupons.io/docs/extras/#custom-css'),
		'wp_coupons_print_custom_css',
		'wp_coupons_extra_options',
		'wp_coupons_extra_settings'
	);
	
	//before archive content
	add_settings_field(
		'wp_coupons_before_archive_content',
		wp_coupons_title(__('Before Archive Content', 'wp_coupons'), 'wp_coupons_before_archive_content') . wp_coupons_tooltip('https://wpcoupons.io/docs/extras/#before-archive-content'),
		'wp_coupons_print_before_archive_content',
		'wp_coupons_extra_options',
		'wp_coupons_extra_settings'
	);
	
	//after archive content
	add_settings_field(
		'wp_coupons_after_archive_content',
		wp_coupons_title(__('After Archive Content', 'wp_coupons'), 'wp_coupons_after_archive_content') . wp_coupons_tooltip('https://wpcoupons.io/docs/extras/#after-archive-content'),
		'wp_coupons_print_after_archive_content',
		'wp_coupons_extra_options',
		'wp_coupons_extra_settings'
	);

	//Management Roles
    add_settings_field(
        'wp_coupons_management_roles', 
        wp_coupons_title(__('Coupon Management Roles', 'wp_coupons'), 'wp_coupons_management_roles') . wp_coupons_tooltip('https://wpcoupons.io/docs/extras/#management-roles'), 
        'wp_coupons_print_management_roles', 
        'wp_coupons_extra_options', 
        'wp_coupons_extra_settings', 
        array(
            'id' => 'wp_coupons_management_roles',
            'option' => 'wp_coupons_extra_options'
        )
    );

	//Clean Uninstall
    add_settings_field(
        'wp_coupons_clean_uninstall', 
        wp_coupons_title(__('Clean Uninstall', 'wp_coupons'), 'wp_coupons_clean_uninstall') . wp_coupons_tooltip('https://wpcoupons.io/docs/extras/#clean-uninstall'), 
        'wp_coupons_print_input', 
        'wp_coupons_extra_options', 
        'wp_coupons_extra_settings', 
        array(
            'id' => 'wp_coupons_clean_uninstall',
            'option' => 'wp_coupons_extra_options',
            'tooltip' => __('When enabled, this will cause all WP Coupons options data to be removed from your database when the plugin is uninstalled.', 'wp_coupons')
        )
    );

	//Accessibility Mode
	add_settings_field(
		'wp_coupons_accessibility_mode',
		wp_coupons_title(__('Accessibility Mode', 'wp_coupons'), 'wp_coupons_accessibility_mode', true) . wp_coupons_tooltip('https://wpcoupons.io/docs/extras/#accessibility-mode'),
		'wp_coupons_print_input',
		'wp_coupons_extra_options',
		'wp_coupons_extra_settings',
		array(
			'option' => 'wp_coupons_extra_options',
			'input' => 'checkbox',
			'id'       => 'wp_coupons_accessibility_mode',
			'tooltip'  => __('Disable the use of visual UI elements in the plugin settings such as checkbox toggles and hovering tooltips.', 'wp_coupons')
		)
	);

	register_setting('wp_coupons_extra_options', 'wp_coupons_extra_options');
}

function wp_coupons_print_custom_css($args) {
	$options = get_option('wp_coupons_extra_options');
	$html = '<textarea id="wp-coupons-custom-css" name="wp_coupons_extra_options[wp_coupons_custom_css]" style="width: 500px; height: 200px;">'; 
		if(!empty($options['wp_coupons_custom_css'])) {
			$html.= $options['wp_coupons_custom_css'];
		} 
	$html.= '</textarea>'; 
	$html.= '<p style="font-size: 12px; font-style: italic;">' . __('Add your custom css here.', 'wp_coupons') . '</p>'; 
	echo $html;
}
function wp_coupons_print_before_archive_content($args) {
	$options = get_option('wp_coupons_extra_options');
	if(!empty($options['wp_coupons_before_archive_content'])){$before_archive_content = $options['wp_coupons_before_archive_content'];}else{$before_archive_content = '';}
	$html = wp_editor( $before_archive_content, 'wp-coupons-before-archive-content', array('textarea_name' => 'wp_coupons_extra_options[wp_coupons_before_archive_content]', 'wpautop' => false, 'editor_height' => '200px'));
	$html.= '<p style="font-size: 12px; font-style: italic;">' . __('Add content here to print above your coupons on the main archive template.', 'wp_coupons') . '</p>'; 
	echo $html;
}
function wp_coupons_print_after_archive_content($args) {
	$options = get_option('wp_coupons_extra_options');
	if(!empty($options['wp_coupons_after_archive_content'])){$after_archive_content = $options['wp_coupons_after_archive_content'];}else{$after_archive_content = '';}
	$html= wp_editor( $after_archive_content, 'wp-coupons-after-archive-content', array('textarea_name' => 'wp_coupons_extra_options[wp_coupons_after_archive_content]', 'wpautop' => false, 'editor_height' => '200px'));
	$html.= '<p style="font-size: 12px; font-style: italic;">' . __('Add content here to print below your coupons on the main archive template.', 'wp_coupons') . '</p>'; 
	echo $html;
}
function wp_coupons_print_management_roles($args) {
	$options = get_option('wp_coupons_extra_options');
	if(!empty($options[$args['id']])){$management_roles = $options[$args['id']];}else{$management_roles = array('administrator');}
	
	$html = "";
	$html.= "<div>";

		foreach(get_editable_roles() as $role_name => $role_info) {
			$html.= "<label for='" . $args['id'] . "-" . $role_name . "' style='display: inline-block; margin: 0px 15px 10px 0px;'>";
			$html.= "<input type='checkbox' id='" . $args['id'] . "-" . $role_name . "' name='" . $args['option'] . "[" . $args['id'] . "][]' value='" . $role_name . "'";
			$html.= $role_name == 'administrator' ? " disabled" : "";
			$html.= in_array($role_name, $management_roles) ? " checked" : "";
			$html.= " />";
			$html.= "" . $role_name . "</label>";
			$html.= "<input type='hidden' name='" . $args['option'] . "[" . $args['id'] . "][0]' value='administrator' />";
		}

	$html.= "</div>";
	$html.= "<p style='font-size: 12px; font-style: italic;'>" . __("Choose which roles have access to manage Coupon posts.", 'perfmatters') . "</p>";

	echo $html;
}

function wp_coupons_update_extra_options($old_value, $new_value) {
	if(!empty($_POST['option_page']) && $_POST['option_page'] == 'wp_coupons_extra_options') {
		if($old_value['wp_coupons_management_roles'] !== $new_value['wp_coupons_management_roles']) {

			$extras = get_option('wp_coupons_extra_options');

			$roles = array('administrator');

			//add additional management roles
		 	if(!empty($extras['wp_coupons_management_roles']) && is_array($extras['wp_coupons_management_roles'])) {
		 		$roles = array_unique(array_merge($roles, $extras['wp_coupons_management_roles']));
		 	}

		 	foreach(get_editable_roles() as $role_name => $role_info) {

		 		$role = get_role($role_name);

		 		if(!in_array($role_name, $roles)) {
		 			$role->remove_cap('read_coupon');
					$role->remove_cap('read_private_coupons');
					$role->remove_cap('edit_coupon');
					$role->remove_cap('edit_coupons');
					$role->remove_cap('edit_others_coupons');
					$role->remove_cap('edit_published_coupons');
					$role->remove_cap('publish_coupons');
					$role->remove_cap('delete_others_coupons');
					$role->remove_cap('delete_private_coupons');
					$role->remove_cap('delete_published_coupons');
		 		}
		 		else {
					$role->add_cap('read_coupon');
					$role->add_cap('read_private_coupons');
					$role->add_cap('edit_coupon');
					$role->add_cap('edit_coupons');
					$role->add_cap('edit_others_coupons');
					$role->add_cap('edit_published_coupons');
					$role->add_cap('publish_coupons');
					$role->add_cap('delete_others_coupons');
					$role->add_cap('delete_private_coupons');
					$role->add_cap('delete_published_coupons');
		 		}
		 	}
		}
	}
}
add_action('update_option_wp_coupons_extra_options', 'wp_coupons_update_extra_options', 10, 2);