<?php

//default styling options
function wp_coupons_default_styling_options() {
	$defaults = array(
		'wp_coupons_panel_background_color'           => '#e6e9ee',
		'wp_coupons_discount_background_color'        => '#2c3644',
		'wp_coupons_discount_text_color'              => '#ffffff',
		'wp_coupons_expiration_text_color'            => '#999999',
		'wp_coupons_discount_code_background_color'   => '#237dac',
		'wp_coupons_discount_code_text_color'         => '#ffffff',
		'wp_coupons_ctr_folded_corner_color'          => '#1f6e96',
		'wp_coupons_link_accent_color'                => '#237dac',
		'wp_coupons_link_accent_color_hover'          => '#0872aa',
		'wp_coupons_separator_color'		          => '#d0d2d7',
		'wp_coupons_type_text_color'		          => '#2c3644',
		'wp_coupons_title_font_size'                  => '20px',
		'wp_coupons_description_font_size'            => '18px',
		'wp_coupons_description_line_height'          => '28px',
		'wp_coupons_type_font_size'                   => '16px',
		'wp_coupons_cta_font_size'                    => '16px',
		'wp_coupons_discount_font_size'               => '16px',
		'wp_coupons_expiration_font_size'             => '14px',
		'wp_coupons_discount_code_font_size'          => '16px',
		'wp_coupons_button_font_size'                 => '16px',
		'wp_coupons_nav_font_size'                    => '24px',
		'wp_coupons_subnav_font_size'                 => '18px'
	);
	return apply_filters('wp_coupons_default_styling_options', $defaults);
}

//initialize styling options
function wp_coupons_initialize_styling_options() {

	//get/create option
	if(get_option('wp_coupons_styling_options') == false) {	
		add_option('wp_coupons_styling_options', apply_filters('wp_coupons_default_styling_options', wp_coupons_default_styling_options()));
	}

	//colors section
	add_settings_section('wp_coupons_colors', __('Colors', 'wp_coupons'), __('Change the color scheme for your coupons.', 'wp_coupons'), 'wp_coupons_styling_options');

	//coupon background color
	add_settings_field(
		'wp_coupons_panel_background_color',
		wp_coupons_title(__('Coupon Background Color', 'wp_coupons'), 'wp_coupons_panel_background_color') . wp_coupons_tooltip('https://wpcoupons.io/docs/style-options/#coupon-background-color'),
		'wp_coupons_print_input',
		'wp_coupons_styling_options',
		'wp_coupons_colors',
		array(
			'option' => 'wp_coupons_styling_options',
			'input' => 'color',
			'id' => 'wp_coupons_panel_background_color',
			'tooltip' => __('This will change the background color of the coupons in all views (Archive, Single, Widget, Shortcode).', 'wp_coupons')
		)
	);

	//discount background color
	add_settings_field(
		'wp_coupons_discount_background_color',
		wp_coupons_title(__('Discount Background Color', 'wp_coupons'), 'wp_coupons_discount_background_color') . wp_coupons_tooltip('https://wpcoupons.io/docs/style-options/#discount-background-color'),
		'wp_coupons_print_input',
		'wp_coupons_styling_options',
		'wp_coupons_colors',
		array(
			'option' => 'wp_coupons_styling_options',
			'input' => 'color',
			'id' => 'wp_coupons_discount_background_color',
			'tooltip' => __('This will change the background color of the discount box in all views (Archive, Single, Widget, Shortcode).', 'wp_coupons')
		)
	);

	//discount text color
	add_settings_field(
		'wp_coupons_discount_text_color',
		wp_coupons_title(__('Discount Text Color', 'wp_coupons'), 'wp_coupons_discount_text_color') . wp_coupons_tooltip('https://wpcoupons.io/docs/style-options/#discount-text-color'),
		'wp_coupons_print_input',
		'wp_coupons_styling_options',
		'wp_coupons_colors',
		array(
			'option' => 'wp_coupons_styling_options',
			'input' => 'color',
			'id' => 'wp_coupons_discount_text_color',
			'tooltip' => __('This will change the discount text color in all views (Archive, Single, Widget, Shortcode).', 'wp_coupons')
		)
	);
	
	//expiration date text color
	add_settings_field(
		'wp_coupons_expiration_text_color',
		wp_coupons_title(__('Expiration Date Text Color', 'wp_coupons'), 'wp_coupons_expiration_text_color') . wp_coupons_tooltip('https://wpcoupons.io/docs/style-options/#expiration-date-text-color'),
		'wp_coupons_print_input',
		'wp_coupons_styling_options',
		'wp_coupons_colors',
		array(
			'option' => 'wp_coupons_styling_options',
			'input' => 'color',
			'id' => 'wp_coupons_expiration_text_color',
			'tooltip' => __('This will change the expiration date text color in all views (Archive, Single, Widget, Shortcode).', 'wp_coupons')
		)
	);
	
	//discount code background color
	add_settings_field(
		'wp_coupons_discount_code_background_color',
		wp_coupons_title(__('Discount Code Background Color', 'wp_coupons'), 'wp_coupons_discount_code_background_color') . wp_coupons_tooltip('https://wpcoupons.io/docs/style-options/#discount-code-background-color'),
		'wp_coupons_print_input',
		'wp_coupons_styling_options',
		'wp_coupons_colors',
		array(
			'option' => 'wp_coupons_styling_options',
			'input' => 'color',
			'id' => 'wp_coupons_discount_code_background_color',
			'tooltip' => __('This will change the background color of the discount code box in all views (Archive, Single, Widget, Shortcode).', 'wp_coupons')
		)
	);

	//discount code text color
	add_settings_field(
		'wp_coupons_discount_code_text_color',
		wp_coupons_title(__('Discount Code Text Color', 'wp_coupons'), 'wp_coupons_discount_code_text_color') . wp_coupons_tooltip('https://wpcoupons.io/docs/style-options/#discount-code-text-color'),
		'wp_coupons_print_input',
		'wp_coupons_styling_options',
		'wp_coupons_colors',
		array(
			'option' => 'wp_coupons_styling_options',
			'input' => 'color',
			'id' => 'wp_coupons_discount_code_text_color',
			'tooltip' => __('This will change the discount code text color in all views (Archive, Single, Widget, Shortcode).', 'wp_coupons')
		)
	);

	//click to reveal folded corner color
	add_settings_field(
		'wp_coupons_ctr_folded_corner_color',
		wp_coupons_title(__('CTR Folded Corner Color', 'wp_coupons'), 'wp_coupons_ctr_folded_corner_color') . wp_coupons_tooltip('https://wpcoupons.io/docs/click-to-reveal-coupons'),
		'wp_coupons_print_input',
		'wp_coupons_styling_options',
		'wp_coupons_colors',
		array(
			'option' => 'wp_coupons_styling_options',
			'input' => 'color',
			'id' => 'wp_coupons_ctr_folded_corner_color',
			'tooltip' => __('This will change the color of the folded corner on the Click to Reveal coupon panel buttons (Archive, Widget, Shortcode).', 'wp_coupons')
		)
	);
	
	
	//link accent color
	add_settings_field(
		'wp_coupons_link_accent_color',
		wp_coupons_title(__('Link Accent Color', 'wp_coupons'), 'wp_coupons_link_accent_color') . wp_coupons_tooltip('https://wpcoupons.io/docs/style-options/#link-accent-color'),
		'wp_coupons_print_input',
		'wp_coupons_styling_options',
		'wp_coupons_colors',
		array(
			'option' => 'wp_coupons_styling_options',
			'input' => 'color',
			'id' => 'wp_coupons_link_accent_color',
			'tooltip' => __('This will change the accent color for text links and buttons in all views (Archive, Single, Widget, Shortcode).', 'wp_coupons')
		)
	);
	
	//link accent color on hover
	add_settings_field(
		'wp_coupons_link_accent_color_hover',
		wp_coupons_title(__('Link Accent Color on Hover', 'wp_coupons'), 'wp_coupons_link_accent_color_hover') . wp_coupons_tooltip('https://wpcoupons.io/docs/style-options/#link-accent-color-hover'),
		'wp_coupons_print_input',
		'wp_coupons_styling_options',
		'wp_coupons_colors',
		array(
			'option' => 'wp_coupons_styling_options',
			'input' => 'color',
			'id' => 'wp_coupons_link_accent_color_hover',
			'tooltip' => __('This will change the accent color on hover for text links and buttons in all views (Archive, Single, Widget, Shortcode).', 'wp_coupons')
		)
	);
	
	//separator color
	add_settings_field(
		'wp_coupons_separator_color',
		wp_coupons_title(__('Separator Color', 'wp_coupons'), 'wp_coupons_separator_color') . wp_coupons_tooltip('https://wpcoupons.io/docs/style-options/#separator-color'),
		'wp_coupons_print_input',
		'wp_coupons_styling_options',
		'wp_coupons_colors',
		array(
			'option' => 'wp_coupons_styling_options',
			'input' => 'color',
			'id' => 'wp_coupons_separator_color',
			'tooltip' => __('This will change the color of the separator (hr) used in the archive view.', 'wp_coupons')
		)
	);
	
	//coupon type text color
	add_settings_field(
		'wp_coupons_type_text_color',
		wp_coupons_title(__('Coupon Type Text Color', 'wp_coupons'), 'wp_coupons_type_text_color') . wp_coupons_tooltip('https://wpcoupons.io/docs/style-options/#coupon-type-text-color'),
		'wp_coupons_print_input',
		'wp_coupons_styling_options',
		'wp_coupons_colors',
		array(
			'option' => 'wp_coupons_styling_options',
			'input' => 'color',
			'id' => 'wp_coupons_type_text_color',
			'tooltip' => __('This will change the text color of the coupon type used in the archive view.', 'wp_coupons')
		)
	);
	
	//fonts section
	add_settings_section('wp_coupons_fonts', __('Fonts', 'wp_coupons'), __('Change the various font options for your coupons.', 'wp_coupons'), 'wp_coupons_styling_options');

	//coupon title font size
	add_settings_field(
		'wp_coupons_title_font_size',
		wp_coupons_title(__('Coupon Title Font Size', 'wp_coupons'), 'wp_coupons_title_font_size') . wp_coupons_tooltip('https://wpcoupons.io/docs/style-options/#coupon-title-font-size'),
		'wp_coupons_print_input',
		'wp_coupons_styling_options',
		'wp_coupons_fonts',
		array(
			'option' => 'wp_coupons_styling_options',
			'input' => 'text',
			'id' => 'wp_coupons_title_font_size',
			'tooltip' => __('This will change the font size of your coupon titles. Default: 20px', 'wp_coupons')
		)
	);

	//coupon description
	add_settings_field(
		'wp_coupons_description_font_size',
		wp_coupons_title(__('Coupon Description Font Size', 'wp_coupons'), 'wp_coupons_description_font_size') . wp_coupons_tooltip('https://wpcoupons.io/docs/style-options/#coupon-description-font-size'),
		'wp_coupons_print_input',
		'wp_coupons_styling_options',
		'wp_coupons_fonts',
		array(
			'option' => 'wp_coupons_styling_options',
			'input' => 'text',
			'id' => 'wp_coupons_description_font_size',
			'tooltip' => __('This will change the font size of your coupon descriptions. Default: 18px', 'wp_coupons')
		)
	);

	//coupon description line height
	add_settings_field(
		'wp_coupons_description_line_height',
		wp_coupons_title(__('Coupon Description Line Height', 'wp_coupons'), 'wp_coupons_description_line_height') . wp_coupons_tooltip('https://wpcoupons.io/docs/style-options/#coupon-description-line-height'),
		'wp_coupons_print_input',
		'wp_coupons_styling_options',
		'wp_coupons_fonts',
		array(
			'option' => 'wp_coupons_styling_options',
			'input' => 'text',
			'id' => 'wp_coupons_description_line_height',
			'tooltip' => __('This will change the line height of your coupon descriptions. Default: 28px', 'wp_coupons')
		)
	);
	
	//coupon type font size
	add_settings_field(
		'wp_coupons_type_font_size',
		wp_coupons_title(__('Coupon Type Font Size', 'wp_coupons'), 'wp_coupons_type_font_size') . wp_coupons_tooltip('https://wpcoupons.io/docs/style-options/#coupon-type-font-size'),
		'wp_coupons_print_input',
		'wp_coupons_styling_options',
		'wp_coupons_fonts',
		array(
			'option' => 'wp_coupons_styling_options',
			'input' => 'text',
			'id' => 'wp_coupons_type_font_size',
			'tooltip' => __('This will change the font size of your coupon types. Default: 16px', 'wp_coupons')
		)
	);
	
	//call to action font size
	add_settings_field(
		'wp_coupons_cta_font_size',
		wp_coupons_title(__('Call to Action Font Size', 'wp_coupons'), 'wp_coupons_cta_font_size') . wp_coupons_tooltip('https://wpcoupons.io/docs/style-options/#call-to-action-font-size'),
		'wp_coupons_print_input',
		'wp_coupons_styling_options',
		'wp_coupons_fonts',
		array(
			'option' => 'wp_coupons_styling_options',
			'input' => 'text',
			'id' => 'wp_coupons_cta_font_size',
			'tooltip' => __('This will change the font size of your coupon call to actions. Default: 16px', 'wp_coupons')
		)
	);
	
	//coupon discount font size
	add_settings_field(
		'wp_coupons_discount_font_size',
		wp_coupons_title(__('Coupon Discount Font Size', 'wp_coupons'), 'wp_coupons_discount_font_size') . wp_coupons_tooltip('https://wpcoupons.io/docs/style-options/#coupon-discount-font-size'),
		'wp_coupons_print_input',
		'wp_coupons_styling_options',
		'wp_coupons_fonts',
		array(
			'option' => 'wp_coupons_styling_options',
			'input' => 'text',
			'id' => 'wp_coupons_discount_font_size',
			'tooltip' => __('This will change the font size of your coupon discounts. Default: 16px', 'wp_coupons')
		)
	);
	
	//expiration date font size
	add_settings_field(
		'wp_coupons_expiration_font_size',
		wp_coupons_title(__('Expiration Date Font Size', 'wp_coupons'), 'wp_coupons_expiration_font_size') . wp_coupons_tooltip('https://wpcoupons.io/docs/style-options/#expiration-date-font-size'),
		'wp_coupons_print_input',
		'wp_coupons_styling_options',
		'wp_coupons_fonts',
		array(
			'option' => 'wp_coupons_styling_options',
			'input' => 'text',
			'id' => 'wp_coupons_expiration_font_size',
			'tooltip' => __('This will change the font size of your expiration dates. Default: 14px', 'wp_coupons')
		)
	);
	
	//coupon discount code font size
	add_settings_field(
		'wp_coupons_discount_code_font_size',
		wp_coupons_title(__('Coupon Discount Code Font Size', 'wp_coupons'), 'wp_coupons_discount_code_font_size') . wp_coupons_tooltip('https://wpcoupons.io/docs/style-options/#coupon-discount-code-font-size'),
		'wp_coupons_print_input',
		'wp_coupons_styling_options',
		'wp_coupons_fonts',
		array(
			'option' => 'wp_coupons_styling_options',
			'input' => 'text',
			'id' => 'wp_coupons_discount_code_font_size',
			'tooltip' => __('This will change the font size of your coupon discount codes on the single coupon post template. Default: 16px', 'wp_coupons')
		)
	);
	
	//coupon button font size
	add_settings_field(
		'wp_coupons_button_font_size',
		wp_coupons_title(__('Coupon Button Font Size', 'wp_coupons'), 'wp_coupons_button_font_size') . wp_coupons_tooltip('https://wpcoupons.io/docs/style-options/#coupon-button-font-size'),
		'wp_coupons_print_input',
		'wp_coupons_styling_options',
		'wp_coupons_fonts',
		array(
			'option' => 'wp_coupons_styling_options',
			'input' => 'text',
			'id' => 'wp_coupons_button_font_size',
			'tooltip' => __('This will change the font size of your coupon buttons. Default: 16px', 'wp_coupons')
		)
	);

	//coupon nav font size
	add_settings_field(
		'wp_coupons_nav_font_size',
		wp_coupons_title(__('Coupon Nav Font Size', 'wp_coupons'), 'wp_coupons_nav_font_size') . wp_coupons_tooltip('https://wpcoupons.io/docs/style-options/#coupon-nav-font-size'),
		'wp_coupons_print_input',
		'wp_coupons_styling_options',
		'wp_coupons_fonts',
		array(
			'option' => 'wp_coupons_styling_options',
			'input' => 'text',
			'id' => 'wp_coupons_nav_font_size',
			'tooltip' => __('This will change the font size of your primary navigation on the coupon and shortcode archives. Default: 24px', 'wp_coupons')
		)
	);

	//coupon subnav font size
	add_settings_field(
		'wp_coupons_subnav_font_size',
		wp_coupons_title(__('Coupon Subnav Font Size', 'wp_coupons'), 'wp_coupons_subnav_font_size') . wp_coupons_tooltip('https://wpcoupons.io/docs/style-options/#coupon-subnav-font-size'),
		'wp_coupons_print_input',
		'wp_coupons_styling_options',
		'wp_coupons_fonts',
		array(
			'option' => 'wp_coupons_styling_options',
			'input' => 'text',
			'id' => 'wp_coupons_subnav_font_size',
			'tooltip' => __('This will change the font size of your sub navigation (tags) on the coupon and shortcode archives. Default: 18px', 'wp_coupons')
		)
	);

	register_setting('wp_coupons_styling_options', 'wp_coupons_styling_options');
}