<?php

//register options
require_once('settings-display.php');
require_once('settings-styling.php');
require_once('settings-extra.php');

//initialize plugin options
function wp_coupons_initialize_options() {

	//initialize options functions
	wp_coupons_initialize_display_options();
	wp_coupons_initialize_styling_options();
	wp_coupons_initialize_extra_options();

	//edd license options
	register_setting('wp_coupons_edd_license', 'wp_coupons_edd_license_key', 'wp_coupons_edd_sanitize_license');
}
add_action('admin_init','wp_coupons_initialize_options');

//print section
function wp_coupons_section($page, $section) {
	global $wp_settings_sections;
	if(!empty($wp_settings_sections[$page][$section])) {
		echo '<div class="wp-coupons-section-heading">';
		echo '<h2>' . __($wp_settings_sections[$page][$section]['title'], 'wp_coupons') . '</h2>';
		echo '<p>' . __($wp_settings_sections[$page][$section]['callback'], 'wp_coupons') . '</p>';
		echo '</div>';

		echo "<table class='form-table'>";
			echo "<tbody>";
				do_settings_fields($page, $section);
			echo "</tbody>";
		echo "</table>";
	}
}

//edd license functions
function wp_coupons_edd_sanitize_license($new) {
	$old = get_option( 'wp_coupons_edd_license_key' );
	if($old && $old != $new) {
		delete_option( 'wp_coupons_edd_license_status' ); // new license has been entered, so must reactivate
	}
	return $new;
}

//print form inputs
function wp_coupons_print_input($args) {
    if(!empty($args['option'])) {
        $option = $args['option'];
        $options = get_option($args['option']);
    }
    else {
        $option = 'wp_coupons_display_options';
        $options = get_option('wp_coupons_display_options');
    }
    if(!empty($args['option']) && $args['option'] == 'wp_coupons_extra_options') {
        $extras = $options;
    }
    else {
        $extras = get_option('wp_coupons_extra_options');
    }

    echo "<div style='display: table; width: 100%;'>";
    	echo "<div class='wp-coupons-input-wrapper'>";

    		//Text + Color
    		if(!empty($args['input']) && ($args['input'] == 'text' || $args['input'] == 'color')) {
    			echo "<input type='text' id='" . $args['id'] . "' name='" . $option . "[" . $args['id'] . "]'";
    				if($args['input'] == 'color') {
    					echo " class='wp-coupons-color-picker'";
    				}
    			echo " value='" . (!empty($options[$args['id']]) ? $options[$args['id']] : '') . "' />";
    		}

    		//Select
    		elseif(!empty($args['input']) && $args['input'] == 'select') {
    			echo "<select id='" . $args['id'] . "' name='" . $option . "[" . $args['id'] . "]'>";
					foreach($args['options'] as $value => $title) {
						echo "<option value='" . $value . "' "; 
						if(!empty($options[$args['id']]) && $options[$args['id']] == $value || (empty($options[$args['id']]) && empty($value))) {
							echo "selected";
						} 
						echo ">" . $title . "</option>";
					}
				echo "</select>";
    		}

    		//Text Area
    		elseif(!empty($args['input']) && $args['input'] == 'textarea') {
    			echo "<textarea id='" . $args['id'] . "' name='" . $option . "[" . $args['id'] . "]'>";
    				echo (!empty($options[$args['id']]) ? $options[$args['id']] : '');
    			echo "</textarea>";
    		}

    		//Image
    		elseif(!empty($args['input']) && $args['input'] == 'image') {
    			echo "<input type='text' id='" . $args['id'] . "' name='" . $option . "[" . $args['id'] . "]' value='" . (!empty($options[$args['id']]) ? $options[$args['id']] : '') . "' />";
				echo "<a class='upload_image_button button button-secondary' value='" . $args['id'] . "' frame_title='" . __('Select an Image', 'wp_coupons') . "'>" . __('Upload', 'wp_coupons') . "</a>";
    		}

    		//Checkbox + Toggle
    		else {

			    if((empty($extras['wp_coupons_accessibility_mode']) || $extras['wp_coupons_accessibility_mode'] != "1") && (empty($args['input']) || $args['input'] != 'checkbox')) {
			        echo "<label for='" . $args['id'] . "' class='switch'>";
			    }
			    	echo "<input type='checkbox' id='" . $args['id'] . "' name='" . $option . "[" . $args['id'] . "]' value='1' style='display: block; margin: 0px;' ";
			    	if(!empty($options[$args['id']]) && $options[$args['id']] == "1") {
			    		echo "checked";
			    	}
			        echo ">";
			    if((empty($extras['wp_coupons_accessibility_mode']) || $extras['wp_coupons_accessibility_mode'] != "1") && (empty($args['input']) || $args['input'] != 'checkbox')) {
				       echo "<div class='slider'></div>";
				   echo "</label>";
			    }
    		}
    		

	    echo "</div>";
	    if(!empty($args['tooltip'])) {
	    	if((empty($extras['wp_coupons_accessibility_mode']) || $extras['wp_coupons_accessibility_mode'] != "1") && $args['id'] != 'wp_coupons_accessibility_mode') {
	    		echo "<div class='wp-coupons-tooltip-text-wrapper'>";
		    		echo "<div class='wp-coupons-tooltip-text-container'>";
		    			echo "<div style='display: table; height: 100%; width: 100%;'>";
		    				echo "<div style='display: table-cell; vertical-align: middle;'>";
		    					echo "<span class='wp-coupons-tooltip-text'>" . $args['tooltip'] . "</span>";
		    				echo "</div>";
		    			echo "</div>";
		    		echo "</div>";
		    	echo "</div>";
	    	}
	    	else {
	    		echo "<p style='font-size: 12px; font-style: italic;'>" . $args['tooltip'] . "</p>";
	    	}
	    	
	    }
	echo "</div>";
}

//print tooltip
function wp_coupons_tooltip($link) {
	$var = "<a ";
		if(!empty($link)) {
			$var.= "href='" . $link . "' title='" . __('View Documentation', 'wp_coupons') . "' ";
		}
		$var.= "class='wp-coupons-tooltip' target='_blank'>?";
	$var.= "</a>";
	return $var;
}

//print title
function wp_coupons_title($title, $id, $checkbox = false) {
    if(!empty($title)) {
        $var = $title;
        if(!empty($id)) {
            $extras = get_option('wp_coupons_extra_options');
            if((!empty($extras['wp_coupons_accessibility_mode']) && $extras['wp_coupons_accessibility_mode'] == "1") || $checkbox == true) {
                $var = "<label for='" . $id . "'>" . $var . "</label>";
            }
        }
        return $var;
    }
}

//return array of all published coupons
function wp_coupons_coupon_array() {
	$args = array(
		'posts_per_page'   => -1,
		'post_type'        => 'coupon',
		'post_status'      => 'publish',
		'order_by'         => 'title'
	);
	$coupon_array = get_posts($args);
	$options = array('' => __('Select a Coupon', 'wp_coupons'));
	foreach($coupon_array as $coupon) {
		$options[$coupon->ID] = $coupon->post_title;
	}
	return $options;
}