<?php
//Coupon Widget For Display Around Site
class wp_coupons_widget extends WP_Widget {

	function __construct() {

		parent::__construct(
			'wp_coupons_widget', // Base ID of your widget
			__('WP Coupons Widget', 'wp_coupons'),
			array('description' => __('Display a randomly selected coupon on your sidebar. See individual post meta box to force a specific coupon per post.', 'wp_coupons'))
		);
	}

	// Creating widget front-end
	public function widget( $widget_args, $instance ) {

		$wp_coupons_display = get_option('wp_coupons_display_options');
		$wp_coupons_extra = get_option('wp_coupons_extra_options');

		$widget_content = "";

		$widget_content.= wp_coupons_css_overrides();

		$title = apply_filters( 'widget_title', $instance['title'] );

		// before and after widget arguments are defined by themes
		echo $widget_args['before_widget'];
		if ( ! empty( $title ) )
		echo $widget_args['before_title'] . $title . $widget_args['after_title'];

		//get the current post id
		$current_post = get_queried_object();
		if($current_post) {
			$current_post_id = $current_post->ID;
			$post_coupon = get_post_meta($current_post_id, "wp_coupons_coupon_post_id", true); //post specific coupon
		}

		if(!empty($_GET['wpcctr'])) {
			$post_coupon = $_GET['wpcctr'];
		}

		//check if we need to force a coupon for this post
		if(empty($post_coupon)) {
			if(!empty($wp_coupons_display['wp_coupons_force_home']) && is_home()) {
				$args = array('post_type'=>'coupon', 'p' => $wp_coupons_display['wp_coupons_force_home']); //force home page coupon
			}
			elseif(!empty($wp_coupons_display['wp_coupons_force_global_widget'])) {
				$args = array('post_type'=>'coupon', 'p' => $wp_coupons_display['wp_coupons_force_global_widget']); //force global widget coupon
			}
			else {
				$excluded_posts = get_posts(array(
					'post_type'      => 'coupon',
					'posts_per_page' => -1,
				    'meta_key'       => 'wp_coupons_exclude_rotation',
				    'meta_value'     => '1'
				));
				$excluded_post_ids = array();
				if(!empty($excluded_posts)) {
					foreach($excluded_posts as $key => $value)
					{
						array_push($excluded_post_ids, $value->ID);
					}
				}
				$args = array('post_type'=>'coupon', 'orderby'=>'rand', 'posts_per_page'=>'1', 'post__not_in' => $excluded_post_ids); //no forced coupon is set
				remove_all_filters('posts_orderby');
			}
		}
		else {
			$args = array('post_type'=>'coupon', 'p' => $post_coupon); //force post specific coupon
		}

		$coupon = new WP_Query($args);

		while ($coupon->have_posts()) : $coupon->the_post();

			$widget_content.= "<div class='wp-coupons-widget'>";

				$widget_content.= wp_coupons_coupon_panel(get_the_ID(), $params = array('button' => true));

			$widget_content.= "</div>";

		  	if(!empty($wp_coupons_display['wp_coupons_attribution']) && $wp_coupons_display['wp_coupons_attribution'] == '1') {
		  		$affiliate_id = "";
		  		if(!empty($wp_coupons_display['wp_coupons_affiliate_id'])) { 
		  			$affiliate_id = "?ref=" . $wp_coupons_display['wp_coupons_affiliate_id'];
		  		}
		  		else {
		  			$affiliate_id = "";
		  		}
		  		$widget_content.= "<div class='wp-coupons-attribution-link' style=''><a href='https://wpcoupons.io/" . $affiliate_id . "' rel='nofollow' target='_blank'><i class='fa fa-info'></i> " . __('Powered by WP Coupons', 'wp_coupons') . "</a></div>";
		  	}

		endwhile;
		wp_reset_postdata();

		//clipboard.js inline script
		if(!empty($wp_coupons_extra['wp_coupons_clipboard_js']) && $wp_coupons_extra['wp_coupons_clipboard_js'] == "1") {
			if(has_action('wp_footer', 'wp_coupons_output_clipboard_js') == false) {
				add_action('wp_footer', 'wp_coupons_output_clipboard_js');
			}
		}

		//click to reveal popup
		if(!empty($wp_coupons_display['wp_coupons_click_to_reveal'])) {
			if(has_action('wp_footer', 'wp_coupons_output_ctr_popup') == false) {
				add_action('wp_footer', 'wp_coupons_output_ctr_popup');
			}
		}

		//run the code and display the output
		echo __( $widget_content, 'wp_coupons_widget_domain' );
		echo $widget_args['after_widget'];
	}
			
	// Widget Backend 
	public function form($instance) {

		if(isset( $instance['title'])) {
			$title = $instance['title'];
		}
		else {
			$title = __('New title', 'wp_coupons');
		}
		// Widget admin form
		?>
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e('Title', 'wp_coupons'); ?>:</label> 
			<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo esc_attr($title); ?>" />
		</p>
		<?php 
	}
		
	// Updating widget replacing old instances with new
	public function update( $new_instance, $old_instance ) {
		$instance = array();
		$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
		return $instance;
	}
}

// Register and load the widget
function wp_coupons_load_widget() {
	register_widget( 'wp_coupons_widget' );
}
add_action( 'widgets_init', 'wp_coupons_load_widget' );