<?php
/*
Plugin Name: WP Coupons
Plugin URI: https://wpcoupons.io/
Description: This plugin adds a custom Coupon post type to your WordPress installation as well as other related features.
Version: 1.6.0
Author: 20script
Author URI: https://www.20script.ir/
License: GPLv2 or later
License URI: http://www.gnu.org/licenses/gpl-2.0.html
*/

/*****************************************************************************************
* EDD License
*****************************************************************************************/
define('WP_COUPONS_STORE_URL', 'https://wpcoupons.io/');
define('WP_COUPONS_ITEM_NAME', 'WP Coupons');
define('WP_COUPONS_VERSION', '1.6.0');

//load translations
function wp_coupons_load_textdomain() {
	load_plugin_textdomain('wp_coupons', false, dirname(plugin_basename( __FILE__)) . '/languages/');
}
add_action('plugins_loaded', 'wp_coupons_load_textdomain');

//load edd custom updater
if(!class_exists('EDD_SL_Plugin_Updater')) {
	include(dirname( __FILE__ ) . '/EDD_SL_Plugin_Updater.php');
}

function wp_coupons_edd_plugin_updater() {

	//retrieve our license key from the DB
	$license_key = trim(get_option('wp_coupons_edd_license_key'));

	//setup the updater
	$edd_updater = new EDD_SL_Plugin_Updater(WP_COUPONS_STORE_URL, __FILE__, array(
			'version' 	=> WP_COUPONS_VERSION,
			'license' 	=> $license_key,
			'item_name' => WP_COUPONS_ITEM_NAME,
			'author' 	=> 'forgemedia'
		)
	);
}
add_action('admin_init', 'wp_coupons_edd_plugin_updater', 0);

/*****************************************************************************************
* WP Coupons Plugin Start
*****************************************************************************************/
//add our plugin menu
if(is_admin()) {
	add_action('admin_menu', 'wp_coupons_menu', 9);
}

//plugin menu
function wp_coupons_menu() {
	$pages = add_options_page('WP Coupons', 'WP Coupons', 'manage_options', 'wp_coupons', 'wp_coupons_admin');
	add_action('load-'.$pages,'wp_coupons_flush_permalinks');
}

//plugin main administration/settings page
function wp_coupons_admin() {
	include plugin_dir_path(__FILE__) . 'admin.php';
}

function wp_coupons_flush_permalinks()
{
	//only flush permalinks if we know they clicked save on the display options / extras tab
	if(isset($_GET['settings-updated']) && (!empty($_GET['page']) && $_GET['page'] == 'wp_coupons') && ((!empty($_GET['tab']) && ($_GET['tab'] == 'display' || $_GET['tab'] == 'extra')) || !isset($_GET['tab']))) {
		global $wp_rewrite;
		$wp_rewrite->flush_rules();
	}
}

//add our plugin admin scripts
function wp_coupons_admin_scripts() {
	//admin CSS
	wp_register_style('wp-coupons-admin-styles', plugins_url('/css/admin-style.css', __FILE__), array(), WP_COUPONS_VERSION);
	wp_enqueue_style('wp-coupons-admin-styles');
	//color picker
    wp_enqueue_style('wp-color-picker');
    wp_enqueue_script('wp-coupons-admin-js', plugins_url('/js/admin.js', __FILE__ ), array('wp-color-picker'), WP_COUPONS_VERSION, true);
    wp_enqueue_script( 'jquery-ui-datepicker' );
    //jQuery UI
	wp_register_style('wp-coupons-jquery-ui', 'https://ajax.googleapis.com/ajax/libs/jqueryui/1.12.1/themes/smoothness/jquery-ui.css');
    wp_enqueue_style( 'wp-coupons-jquery-ui' );
    //required for image upload
    wp_enqueue_media();
}
add_action('admin_enqueue_scripts', 'wp_coupons_admin_scripts');

//add our plugin non-admin scripts
function wp_coupons_scripts() {
	$extra_options = get_option('wp_coupons_extra_options');
	//clipboard.js
	if(!empty($extra_options['wp_coupons_clipboard_js']) && $extra_options['wp_coupons_clipboard_js'] == "1") {
		wp_enqueue_script('clipboard-js', plugins_url('/js/clipboard.min.js', __FILE__ ), array(), false, false);
	}
	//CSS
	wp_register_style('wp-coupons-styles', plugins_url('/css/style.css', __FILE__), array(), WP_COUPONS_VERSION);
	wp_enqueue_style('wp-coupons-styles');
}
add_action('wp_enqueue_scripts', 'wp_coupons_scripts');

//all plugin file includes
include plugin_dir_path(__FILE__) . '/includes/settings.php';
include plugin_dir_path(__FILE__) . '/includes/coupon.php';
include plugin_dir_path(__FILE__) . '/includes/widget.php';
include plugin_dir_path(__FILE__) . '/includes/meta.php';
include plugin_dir_path(__FILE__) . '/includes/shortcode.php';
include plugin_dir_path(__FILE__) . '/includes/functions.php';

//force use of templates from plugin folder
function wp_coupons_force_template($template)
{	
	$display_options = get_option('wp_coupons_display_options');
	//using the same archive template for both the custom post type and taxonomy archives
    if(is_post_type_archive('coupon') || is_tax('type')) {
        $template = WP_PLUGIN_DIR . '/' . plugin_basename( dirname(__FILE__) ) . '/templates/archive-coupons.php';
	}
	//single post template
	if(is_singular('coupon')) {
		if(!empty($display_options['wp_coupons_enable_single']) && $display_options['wp_coupons_enable_single'] == "1") {
			$template = WP_PLUGIN_DIR . '/' . plugin_basename( dirname(__FILE__) ) . '/templates/single-coupon.php';
		}
        else {
        	//check the default coupon post template option
        	if(!empty($display_options['wp_coupons_single_template']) && $display_options['wp_coupons_single_template'] == "page") {
        		$template = get_template_directory() . '/page.php';
        	}
        }
	}
    return $template;
}
add_filter('template_include', 'wp_coupons_force_template');

//custom CSS from plugin option
function wp_coupons_custom_css() {
	$extra_options = get_option('wp_coupons_extra_options');
	if(!empty($extra_options['wp_coupons_custom_css'])) {
		echo "<style>";
			echo $extra_options['wp_coupons_custom_css'];
		echo "</style>";
	}
}
add_action('wp_head', 'wp_coupons_custom_css');

//function to run when plugin is activated
function wp_coupons_activate() {

	//register custom post types and taxonomies on actiation
	coupon_init('activate');
	create_coupon_type_tax('activate');
	create_coupon_tag_tax('activate');

	//only run this block the first time the plugin is activated
	if(get_option('wp_coupons_first_activation') != 1) {

		//add admin management capabilities
		$role = get_role('administrator');
		$role->add_cap('read_coupon');
		$role->add_cap('read_private_coupons');
		$role->add_cap('edit_coupon');
		$role->add_cap('edit_coupons');
		$role->add_cap('edit_others_coupons');
		$role->add_cap('edit_published_coupons');
		$role->add_cap('publish_coupons');
		$role->add_cap('delete_others_coupons');
		$role->add_cap('delete_private_coupons');
		$role->add_cap('delete_published_coupons');

    	//create sample coupon post object
		$sample_coupon = array(
		  	'post_title'    => __('Sample Coupon', 'wp_coupons'),
	  		'post_content'  => __('Sample coupon content.', 'wp_coupons'),
		  	'post_status'   => 'publish',
		  	'post_type'     => 'coupon',
		  	'meta_input'    => array(
				'wp_coupons_discount_percent' => __('25% OFF!', 'wp_coupons'), 
				'wp_coupons_discount_code' => __('25OFF', 'wp_coupons'), 
				'wp_coupons_discount_url' => 'https://wpcoupons.io/', 
				'wp_coupons_discount_description' => __('Get 25% off with this sample coupon today!', 'wp_coupons')
			)
		);
		wp_insert_post($sample_coupon);

		//set the activation option so we don't run this block again
		update_option('wp_coupons_first_activation', 1);
    }

    //flush the permalinks
    flush_rewrite_rules();
}
register_activation_hook(__FILE__, 'wp_coupons_activate');

//license messages in plugins table
function wp_coupons_meta_links($links, $file) {
	if(strpos($file, 'wp-coupons.php' ) !== false) {
		$wp_coupons_links = array();
		$wp_coupons_links[] = '<a href="' . admin_url('options-general.php?page=wp_coupons') . '">' . __('Settings', 'wp_coupons') . '</a>';
		$license_info = wp_coupons_edd_check_license();
		if(!empty($license_info->license) && $license_info->license == "valid") {
			$wp_coupons_links[] = '<a href="' . admin_url('options-general.php?page=wp_coupons&tab=license') . '" style="color: green;">' . __('License is Activated', 'wp_coupons') . '</a>';
		}
		elseif(!empty($license_info->license) && $license_info->license == "expired") {
			$wp_coupons_links[] = '<a href="' . admin_url('options-general.php?page=wp_coupons&tab=license') . '" style="color: orange;">' . __('Renew License', 'wp_coupons') . '</a>';
		}
		else {
			$wp_coupons_links[] = '<a href="' . admin_url('options-general.php?page=wp_coupons&tab=license') . '" style="color: red;">' . __('Activate License', 'wp_coupons') . '</a>';
		}
		$links = array_merge($links, $wp_coupons_links);
	}
	return $links;
}
add_filter('plugin_row_meta', 'wp_coupons_meta_links', 10, 2);

//function to register a license deactivation
function wp_coupons_deactivate() {

	// retrieve the license from the database
	$license = trim(get_option('wp_coupons_edd_license_key'));
	$license_status = get_option('wp_coupons_edd_license_status');

	if(!empty($license) && (!empty($license_status) && $license_status == "valid")) {

		// data to send in our API request
		$api_params = array(
			'edd_action'=> 'deactivate_license',
			'license' 	=> $license,
			'item_name' => urlencode(WP_COUPONS_ITEM_NAME),
			'url'       => home_url()
		);

		// Call the custom API.
		$response = wp_remote_post(WP_COUPONS_STORE_URL, array( 'timeout' => 15, 'sslverify' => false, 'body' => $api_params));

		// make sure the response came back okay
		if(is_wp_error($response)) {
			return false;
		}

		// decode the license data
		$license_data = json_decode(wp_remote_retrieve_body($response));

		// $license_data->license will be either "deactivated" or "failed"
		if($license_data->license == 'deactivated') {
			delete_option('wp_coupons_edd_license_status');
		}
	}	
}
register_uninstall_hook(__FILE__, 'wp_coupons_deactivate');

//uninstall plugin + delete options
function wp_coupons_uninstall() {

	//plugin options
	$wp_coupons_options = array(
		'wp_coupons_display_options',
		'wp_coupons_styling_options',
		'wp_coupons_extra_options',
		'wp_coupons_edd_license_key',
		'wp_coupons_edd_license_status'
	);

	$wp_coupons_extras = get_option('wp_coupons_extra_options');
	if(!empty($wp_coupons_extras['wp_coupons_clean_uninstall']) && $wp_coupons_extras['wp_coupons_clean_uninstall'] == 1) {
		foreach($wp_coupons_options as $option) {
			delete_option($option);
		}
	}
}
register_uninstall_hook(__FILE__, 'wp_coupons_uninstall');